# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_client_objects.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.enums_pb2 as enums__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_client_objects.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"steammessages_client_objects.proto\x1a\x0b\x65nums.proto\"\xcb\x02\n0SteamMessagesClientIClientForcedEnumDependencies\x12?\n\x01\x61\x18\x01 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12H\n\x01\x62\x18\x02 \x01(\x0e\x32\x19.EStorageBlockContentType:\"k_EStorageBlockContentType_Invalid\x12N\n\x01\x63\x18\x03 \x01(\x0e\x32\x1c.EStorageBlockFileSystemType:%k_EStorageBlockFileSystemType_Invalid\x12<\n\x01\x64\x18\x04 \x01(\x0e\x32\x13.ESDCardFormatStage:\x1ck_ESDCardFormatStage_Invalid\"=\n\x1b\x43MsgNetworkDeviceIP4Address\x12\r\n\x02ip\x18\x01 \x01(\x05:\x01\x30\x12\x0f\n\x07netmask\x18\x02 \x01(\x05\"\xbf\x01\n\x1a\x43MsgNetworkDeviceIP4Config\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.CMsgNetworkDeviceIP4Address\x12\x0e\n\x06\x64ns_ip\x18\x02 \x03(\x05\x12\x12\n\ngateway_ip\x18\x03 \x01(\x05\x12\x17\n\x0fis_dhcp_enabled\x18\x04 \x01(\x08\x12\x18\n\x10is_default_route\x18\x05 \x01(\x08\x12\x19\n\nis_enabled\x18\x06 \x01(\x08:\x05\x66\x61lse\")\n\x1b\x43MsgNetworkDeviceIP6Address\x12\n\n\x02ip\x18\x01 \x01(\t\"\xbf\x01\n\x1a\x43MsgNetworkDeviceIP6Config\x12/\n\taddresses\x18\x01 \x03(\x0b\x32\x1c.CMsgNetworkDeviceIP6Address\x12\x0e\n\x06\x64ns_ip\x18\x02 \x03(\t\x12\x12\n\ngateway_ip\x18\x03 \x01(\t\x12\x17\n\x0fis_dhcp_enabled\x18\x04 \x01(\x08\x12\x18\n\x10is_default_route\x18\x05 \x01(\x08\x12\x19\n\nis_enabled\x18\x06 \x01(\x08:\x05\x66\x61lse\"\x97\x06\n\x16\x43MsgNetworkDevicesData\x12/\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x1e.CMsgNetworkDevicesData.Device\x12\x17\n\x0fis_wifi_enabled\x18\x02 \x01(\x08\x12 \n\x18is_wifi_scanning_enabled\x18\x03 \x01(\x08\x1a\x90\x05\n\x06\x44\x65vice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\r\n\x05\x65type\x18\x02 \x01(\x05\x12\x0e\n\x06\x65state\x18\x03 \x01(\x05\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x0e\n\x06vendor\x18\x05 \x01(\t\x12\x0f\n\x07product\x18\x06 \x01(\t\x12(\n\x03ip4\x18\x07 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP4Config\x12(\n\x03ip6\x18\x08 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP6Config\x12\x33\n\x05wired\x18\t \x01(\x0b\x32$.CMsgNetworkDevicesData.Device.Wired\x12\x39\n\x08wireless\x18\n \x01(\x0b\x32\'.CMsgNetworkDevicesData.Device.Wireless\x1aS\n\x05Wired\x12\x1f\n\x10is_cable_present\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x12\n\nspeed_mbit\x18\x02 \x01(\r\x12\x15\n\rfriendly_name\x18\x03 \x01(\t\x1a\x90\x02\n\x08Wireless\x12\x37\n\x03\x61ps\x18\x01 \x03(\x0b\x32*.CMsgNetworkDevicesData.Device.Wireless.AP\x12\x1b\n\x13\x65security_supported\x18\x02 \x01(\x05\x1a\xad\x01\n\x02\x41P\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x11\n\testrength\x18\x02 \x01(\x05\x12\x0c\n\x04ssid\x18\x03 \x01(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08\x12\x16\n\x0eis_autoconnect\x18\x05 \x01(\x08\x12\x11\n\tesecurity\x18\x06 \x01(\x05\x12\x11\n\tuser_name\x18\x07 \x01(\t\x12\x10\n\x08password\x18\x08 \x01(\t\x12\x14\n\x0cstrength_raw\x18\t \x01(\x05\"\xb5\x03\n\x18\x43MsgNetworkDeviceConnect\x12\x14\n\tdevice_id\x18\x01 \x01(\r:\x01\x30\x12:\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32%.CMsgNetworkDeviceConnect.Credentials\x12(\n\x03ip4\x18\x05 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP4Config\x12(\n\x03ip6\x18\x06 \x01(\x0b\x32\x1b.CMsgNetworkDeviceIP6Config\x12\x35\n\x08\x61p_known\x18\x02 \x01(\x0b\x32!.CMsgNetworkDeviceConnect.KnownAPH\x00\x12\x37\n\tap_custom\x18\x03 \x01(\x0b\x32\".CMsgNetworkDeviceConnect.CustomAPH\x00\x1a\x18\n\x07KnownAP\x12\r\n\x05\x61p_id\x18\x01 \x01(\r\x1a+\n\x08\x43ustomAP\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x11\n\tesecurity\x18\x02 \x01(\x05\x1a\x31\n\x0b\x43redentials\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\tB\t\n\x07\x61p_info\"\x9b\x05\n\x16\x43MsgStorageDevicesData\x12-\n\x06\x64rives\x18\x01 \x03(\x0b\x32\x1d.CMsgStorageDevicesData.Drive\x12:\n\rblock_devices\x18\x02 \x03(\x0b\x32#.CMsgStorageDevicesData.BlockDevice\x12\x1c\n\x14is_unmount_supported\x18\x03 \x01(\x08\x1ao\n\x05\x44rive\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\r\n\x05model\x18\x02 \x01(\t\x12\x0e\n\x06vendor\x18\x03 \x01(\t\x12\x0e\n\x06serial\x18\x04 \x01(\t\x12\x14\n\x0cis_ejectable\x18\x05 \x01(\x08\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x1a\x86\x03\n\x0b\x42lockDevice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x13\n\x08\x64rive_id\x18\x02 \x01(\r:\x01\x30\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x15\n\rfriendly_path\x18\x04 \x01(\t\x12\r\n\x05label\x18\x05 \x01(\t\x12\x12\n\nsize_bytes\x18\x06 \x01(\x04\x12\x16\n\x0eis_formattable\x18\x07 \x01(\x08\x12\x14\n\x0cis_read_only\x18\x08 \x01(\x08\x12\x16\n\x0eis_root_device\x18\t \x01(\x08\x12S\n\x0c\x63ontent_type\x18\n \x01(\x0e\x32\x19.EStorageBlockContentType:\"k_EStorageBlockContentType_Invalid\x12\\\n\x0f\x66ilesystem_type\x18\x0b \x01(\x0e\x32\x1c.EStorageBlockFileSystemType:%k_EStorageBlockFileSystemType_Invalid\x12\x12\n\nmount_path\x18\x0c \x01(\t\"\xb9\x01\n\x1d\x43\x43loud_PendingRemoteOperation\x12T\n\toperation\x18\x01 \x01(\x0e\x32\x1d.ECloudPendingRemoteOperation:\"k_ECloudPendingRemoteOperationNone\x12\x14\n\x0cmachine_name\x18\x02 \x01(\t\x12\x11\n\tclient_id\x18\x03 \x01(\x04\x12\x19\n\x11time_last_updated\x18\x04 \x01(\r\"V\n CMsgCloudPendingRemoteOperations\x12\x32\n\noperations\x18\x01 \x03(\x0b\x32\x1e.CCloud_PendingRemoteOperation\"\x90\x04\n\x18\x43MsgBluetoothDevicesData\x12\x33\n\x08\x61\x64\x61pters\x18\x01 \x03(\x0b\x32!.CMsgBluetoothDevicesData.Adapter\x12\x31\n\x07\x64\x65vices\x18\x02 \x03(\x0b\x32 .CMsgBluetoothDevicesData.Device\x12\x32\n\x07manager\x18\x03 \x01(\x0b\x32!.CMsgBluetoothDevicesData.Manager\x1a_\n\x07\x41\x64\x61pter\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x0b\n\x03mac\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\x12\x16\n\x0eis_discovering\x18\x05 \x01(\x08\x1a\xcd\x01\n\x06\x44\x65vice\x12\r\n\x02id\x18\x01 \x01(\r:\x01\x30\x12\x15\n\nadapter_id\x18\x02 \x01(\r:\x01\x30\x12\x43\n\x05\x65type\x18\x03 \x01(\x0e\x32\x15.EBluetoothDeviceType:\x1dk_BluetoothDeviceType_Invalid\x12\x0b\n\x03mac\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x14\n\x0cis_connected\x18\x06 \x01(\x08\x12\x11\n\tis_paired\x18\x07 \x01(\x08\x12\x14\n\x0cstrength_raw\x18\x08 \x01(\x05\x1a\'\n\x07Manager\x12\x1c\n\x14is_bluetooth_enabled\x18\x01 \x01(\x08\"<\n\x1d\x43MsgSystemPerfDiagnosticEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa5\x01\n\x1e\x43MsgSystemPerfNetworkInterface\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x16\n\x0etx_bytes_total\x18\x03 \x01(\x03\x12\x16\n\x0erx_bytes_total\x18\x04 \x01(\x03\x12\x18\n\x10tx_bytes_per_sec\x18\x05 \x01(\x05\x12\x18\n\x10rx_bytes_per_sec\x18\x06 \x01(\x05\"\x9c\x01\n\x1c\x43MsgSystemPerfDiagnosticInfo\x12/\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1e.CMsgSystemPerfDiagnosticEntry\x12\x33\n\ninterfaces\x18\x02 \x03(\x0b\x32\x1f.CMsgSystemPerfNetworkInterface\x12\x16\n\x0e\x62\x61ttery_temp_c\x18\x03 \x01(\x02\"\x86\x05\n\x14\x43MsgSystemPerfLimits\x12#\n\x1b\x63pu_governor_manual_min_mhz\x18\x01 \x01(\x05\x12#\n\x1b\x63pu_governor_manual_max_mhz\x18\x02 \x01(\x05\x12\x19\n\x11\x66sr_sharpness_min\x18\x03 \x01(\x05\x12\x19\n\x11\x66sr_sharpness_max\x18\x04 \x01(\x05\x12&\n\x1egpu_performance_manual_min_mhz\x18\x05 \x01(\x05\x12&\n\x1egpu_performance_manual_max_mhz\x18\x06 \x01(\x05\x12\"\n\x1aperf_overlay_is_standalone\x18\x07 \x01(\x08\x12 \n\x18is_dynamic_vrs_available\x18\x08 \x01(\x08\x12\x30\n(is_manual_display_refresh_rate_available\x18\t \x01(\x08\x12?\n gpu_performance_levels_available\x18\n \x03(\x0e\x32\x15.EGPUPerformanceLevel\x12%\n\x1d\x64isplay_refresh_manual_hz_min\x18\x0b \x01(\x05\x12%\n\x1d\x64isplay_refresh_manual_hz_max\x18\x0c \x01(\x05\x12\x19\n\x11\x66ps_limit_options\x18\r \x03(\x05\x12\x15\n\rtdp_limit_min\x18\x0e \x01(\x05\x12\x15\n\rtdp_limit_max\x18\x0f \x01(\x05\x12\x18\n\x10is_nis_supported\x18\x10 \x01(\x08\x12\x19\n\x11nis_sharpness_min\x18\x11 \x01(\x05\x12\x19\n\x11nis_sharpness_max\x18\x12 \x01(\x05\"\x8e\x04\n\x1c\x43MsgSystemPerfSettingsGlobal\x12\x1e\n\x16\x64iagnostic_update_rate\x18\x01 \x01(\x02\x12[\n\x1asystem_trace_service_state\x18\x02 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12\x61\n graphics_profiling_service_state\x18\x03 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12[\n\x1aperf_overlay_service_state\x18\x04 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12Z\n\x12perf_overlay_level\x18\x05 \x01(\x0e\x32\x1a.EGraphicsPerfOverlayLevel:\"k_EGraphicsPerfOverlayLevel_Hidden\x12/\n\'is_show_perf_overlay_over_steam_enabled\x18\x06 \x01(\x08\x12$\n\x1cis_advanced_settings_enabled\x18\x07 \x01(\x08\"\xdd\x04\n\x1c\x43MsgSystemPerfSettingsPerApp\x12\"\n\x1agpu_performance_manual_mhz\x18\x01 \x01(\x05\x12\x11\n\tfps_limit\x18\x02 \x01(\x05\x12&\n\x1eis_variable_resolution_enabled\x18\x03 \x01(\x08\x12\'\n\x1fis_dynamic_refresh_rate_enabled\x18\x04 \x01(\x08\x12\x11\n\ttdp_limit\x18\x05 \x01(\x05\x12;\n\x0c\x63pu_governor\x18\x06 \x01(\x0e\x32\r.ECPUGovernor:\x16k_ECPUGovernor_Invalid\x12\x1f\n\x17\x63pu_governor_manual_mhz\x18\x07 \x01(\x05\x12\x16\n\x0escaling_filter\x18\x08 \x01(\x05\x12\x15\n\rfsr_sharpness\x18\t \x01(\x05\x12\x1c\n\x14is_fps_limit_enabled\x18\n \x01(\x08\x12\x1c\n\x14is_tdp_limit_enabled\x18\x0b \x01(\x08\x12#\n\x1bis_low_latency_mode_enabled\x18\x0c \x01(\x08\x12!\n\x19\x64isplay_refresh_manual_hz\x18\r \x01(\x05\x12$\n\x1cis_game_perf_profile_enabled\x18\x0e \x01(\x08\x12T\n\x15gpu_performance_level\x18\x0f \x01(\x0e\x32\x15.EGPUPerformanceLevel:\x1ek_EGPUPerformanceLevel_Invalid\x12\x15\n\rnis_sharpness\x18\x10 \x01(\x05\"w\n\x16\x43MsgSystemPerfSettings\x12-\n\x06global\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemPerfSettingsGlobal\x12.\n\x07per_app\x18\x02 \x01(\x0b\x32\x1d.CMsgSystemPerfSettingsPerApp\"\x8c\x08\n\x18\x43MsgSystemPerfSettingsV1\x12\x1e\n\x16\x64iagnostic_update_rate\x18\x01 \x01(\x02\x12[\n\x1asystem_trace_service_state\x18\x02 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12\x61\n graphics_profiling_service_state\x18\x03 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12[\n\x1aperf_overlay_service_state\x18\x04 \x01(\x0e\x32\x14.ESystemServiceState:!k_ESystemServiceState_Unavailable\x12Z\n\x12perf_overlay_level\x18\x05 \x01(\x0e\x32\x1a.EGraphicsPerfOverlayLevel:\"k_EGraphicsPerfOverlayLevel_Hidden\x12T\n\x15gpu_performance_level\x18\x06 \x01(\x0e\x32\x15.EGPUPerformanceLevel:\x1ek_EGPUPerformanceLevel_Invalid\x12\"\n\x1agpu_performance_manual_mhz\x18\x07 \x01(\x05\x12\x11\n\tfps_limit\x18\x08 \x01(\x05\x12&\n\x1eis_variable_resolution_enabled\x18\t \x01(\x08\x12\'\n\x1fis_dynamic_refresh_rate_enabled\x18\n \x01(\x08\x12\x11\n\ttdp_limit\x18\x0b \x01(\x05\x12;\n\x0c\x63pu_governor\x18\x0c \x01(\x0e\x32\r.ECPUGovernor:\x16k_ECPUGovernor_Invalid\x12\x1f\n\x17\x63pu_governor_manual_mhz\x18\r \x01(\x05\x12\x16\n\x0escaling_filter\x18\x0e \x01(\x05\x12\x15\n\rfsr_sharpness\x18\x0f \x01(\x05\x12\x1c\n\x14is_fps_limit_enabled\x18\x10 \x01(\x08\x12\x1c\n\x14is_tdp_limit_enabled\x18\x11 \x01(\x08\x12/\n\'is_show_perf_overlay_over_steam_enabled\x18\x12 \x01(\x08\x12#\n\x1bis_low_latency_mode_enabled\x18\x13 \x01(\x08\x12!\n\x19\x64isplay_refresh_manual_hz\x18\x14 \x01(\x05\x12$\n\x1cis_game_perf_profile_enabled\x18\x15 \x01(\x08\"\xa0\x01\n\x13\x43MsgSystemPerfState\x12%\n\x06limits\x18\x01 \x01(\x0b\x32\x15.CMsgSystemPerfLimits\x12)\n\x08settings\x18\x02 \x01(\x0b\x32\x17.CMsgSystemPerfSettings\x12\x17\n\x0f\x63urrent_game_id\x18\x03 \x01(\x04\x12\x1e\n\x16\x61\x63tive_profile_game_id\x18\x04 \x01(\x04\"\x87\x01\n\x1c\x43MsgSystemPerfUpdateSettings\x12\x0e\n\x06gameid\x18\x01 \x01(\x04\x12\x1a\n\x10reset_to_default\x18\x02 \x01(\x08H\x00\x12\x31\n\x0esettings_delta\x18\x03 \x01(\x0b\x32\x17.CMsgSystemPerfSettingsH\x00\x42\x08\n\x06update\"\xdf\x01\n\x19\x43MsgSystemDockUpdateState\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32\x0e.EUpdaterState:\x17k_EUpdaterState_Invalid\x12\x1a\n\x12rtime_last_checked\x18\x02 \x01(\x07\x12\x17\n\x0fversion_current\x18\x03 \x01(\t\x12\x19\n\x11version_available\x18\x04 \x01(\t\x12\x16\n\x0estage_progress\x18\x05 \x01(\x02\x12\"\n\x1artime_estimated_completion\x18\x06 \x01(\x07\"G\n\x13\x43MsgSystemDockState\x12\x30\n\x0cupdate_state\x18\x01 \x01(\x0b\x32\x1a.CMsgSystemDockUpdateState\"2\n\x1c\x43MsgSystemDockUpdateFirmware\x12\x12\n\ncheck_only\x18\x01 \x01(\x08\"\xc5\x01\n\x15\x43MsgSystemAudioVolume\x12\x34\n\x07\x65ntries\x18\x01 \x03(\x0b\x32#.CMsgSystemAudioVolume.ChannelEntry\x12\x10\n\x08is_muted\x18\x02 \x01(\x08\x1a\x64\n\x0c\x43hannelEntry\x12\x44\n\x08\x65\x63hannel\x18\x01 \x01(\x0e\x32\x14.ESystemAudioChannel:\x1ck_SystemAudioChannel_Invalid\x12\x0e\n\x06volume\x18\x02 \x01(\x02\"E\n\x1c\x43MsgSystemAudioManagerObject\x12\n\n\x02id\x18\x01 \x01(\r\x12\x19\n\x11rtime_last_update\x18\x02 \x01(\x07\"\x89\x01\n\x1c\x43MsgSystemAudioManagerDevice\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04nick\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0b\n\x03\x61pi\x18\x05 \x01(\t\"\x81\x02\n\x1a\x43MsgSystemAudioManagerNode\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04nick\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12J\n\nedirection\x18\x06 \x01(\x0e\x32\x16.ESystemAudioDirection:\x1ek_SystemAudioDirection_Invalid\x12&\n\x06volume\x18\x07 \x01(\x0b\x32\x16.CMsgSystemAudioVolume\"\xe2\x02\n\x1a\x43MsgSystemAudioManagerPort\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x0f\n\x07node_id\x18\x03 \x01(\r\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\r\n\x05\x61lias\x18\x05 \x01(\t\x12\x43\n\x05\x65type\x18\x06 \x01(\x0e\x32\x15.ESystemAudioPortType:\x1dk_SystemAudioPortType_Invalid\x12R\n\nedirection\x18\x07 \x01(\x0e\x32\x1a.ESystemAudioPortDirection:\"k_SystemAudioPortDirection_Invalid\x12\x13\n\x0bis_physical\x18\x08 \x01(\x08\x12\x13\n\x0bis_terminal\x18\t \x01(\x08\x12\x12\n\nis_control\x18\n \x01(\x08\x12\x12\n\nis_monitor\x18\x0b \x01(\x08\"\xa7\x01\n\x1a\x43MsgSystemAudioManagerLink\x12+\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32\x1d.CMsgSystemAudioManagerObject\x12\x16\n\x0eoutput_node_id\x18\x02 \x01(\r\x12\x16\n\x0eoutput_port_id\x18\x03 \x01(\r\x12\x15\n\rinput_node_id\x18\x04 \x01(\r\x12\x15\n\rinput_port_id\x18\x05 \x01(\r\"\xd3\x01\n\x1d\x43MsgSystemAudioManagerStateHW\x12.\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x1d.CMsgSystemAudioManagerDevice\x12*\n\x05nodes\x18\x02 \x03(\x0b\x32\x1b.CMsgSystemAudioManagerNode\x12*\n\x05ports\x18\x03 \x03(\x0b\x32\x1b.CMsgSystemAudioManagerPort\x12*\n\x05links\x18\x04 \x03(\x0b\x32\x1b.CMsgSystemAudioManagerLink\"p\n\x1b\x43MsgSystemAudioManagerState\x12\x14\n\x0crtime_filter\x18\x01 \x01(\x07\x12\x0f\n\x07\x63ounter\x18\x02 \x01(\x05\x12*\n\x02hw\x18\x03 \x01(\x0b\x32\x1e.CMsgSystemAudioManagerStateHW\"8\n%CMsgSystemAudioManagerUpdateSomething\x12\x0f\n\x07\x63ounter\x18\x01 \x01(\x05\"\xf5\x08\n\x19\x43MsgSystemManagerSettings\x12*\n\"idle_backlight_dim_battery_seconds\x18\x01 \x01(\x02\x12%\n\x1didle_backlight_dim_ac_seconds\x18\x02 \x01(\x02\x12$\n\x1cidle_suspend_battery_seconds\x18\x03 \x01(\x02\x12\x1f\n\x17idle_suspend_ac_seconds\x18\x04 \x01(\x02\x12\x1e\n\x16idle_suspend_supressed\x18\x05 \x01(\x08\x12(\n is_adaptive_brightness_available\x18\x06 \x01(\x08\x12+\n#display_adaptive_brightness_enabled\x18\x07 \x01(\x08\x12)\n!is_display_colorprofile_available\x18\x08 \x01(\x08\x12\x45\n\x14\x64isplay_colorprofile\x18\t \x01(\x0e\x32\x0e.EColorProfile:\x17k_EColorProfile_Invalid\x12!\n\x19\x64isplay_nightmode_enabled\x18\n \x01(\x08\x12&\n\x1e\x64isplay_nightmode_tintstrength\x18\x0b \x01(\x02\x12 \n\x18\x64isplay_nightmode_maxhue\x18\x0c \x01(\x02\x12 \n\x18\x64isplay_nightmode_maxsat\x18\r \x01(\x02\x12\x1f\n\x17\x64isplay_nightmode_uiexp\x18\x0e \x01(\x02\x12\x1f\n\x17\x64isplay_nightmode_blend\x18\x0f \x01(\x02\x12\x1f\n\x17\x64isplay_nightmode_reset\x18\x10 \x01(\x08\x12*\n\"display_nightmode_schedule_enabled\x18\x11 \x01(\x08\x12,\n$display_nightmode_schedule_starttime\x18\x12 \x01(\x02\x12*\n\"display_nightmode_schedule_endtime\x18\x13 \x01(\x02\x12#\n\x1b\x64isplay_diagnostics_enabled\x18\x14 \x01(\x08\x12\x16\n\x0e\x61ls_lux_latest\x18\x15 \x01(\x02\x12\x16\n\x0e\x61ls_lux_median\x18\x16 \x01(\x02\x12!\n\x19\x64isplay_brightness_linear\x18\x17 \x01(\x02\x12&\n\x1e\x64isplay_brightness_adaptivemin\x18\x18 \x01(\x02\x12&\n\x1e\x64isplay_brightness_adaptivemax\x18\x19 \x01(\x02\x12!\n\x19is_wifi_powersave_enabled\x18\x1a \x01(\x08\x12 \n\x18is_fan_control_available\x18\x1b \x01(\x08\x12P\n\x10\x66\x61n_control_mode\x18\x1c \x01(\x0e\x32\x16.ESystemFanControlMode:\x1ek_SystemFanControlMode_Invalid\"K\n\x18\x43MsgSelectOSBranchParams\x12/\n\x06\x62ranch\x18\x01 \x01(\x0e\x32\n.EOSBranch:\x13k_EOSBranch_Unknown\"p\n\x18\x43MsgSystemUpdateProgress\x12\x16\n\x0estage_progress\x18\x01 \x01(\x02\x12\x18\n\x10stage_size_bytes\x18\x02 \x01(\x03\x12\"\n\x1artime_estimated_completion\x18\x03 \x01(\x07\"\xa1\x01\n\x1b\x43MsgSystemUpdateCheckResult\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32\r.EUpdaterType:\x16k_EUpdaterType_Invalid\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12\x15\n\rrtime_checked\x18\x03 \x01(\x07\x12\x11\n\tavailable\x18\x04 \x01(\x08\x12\x0f\n\x07version\x18\x05 \x01(\t\"A\n\x1b\x43MsgSystemUpdateApplyParams\x12\"\n\x0b\x61pply_types\x18\x01 \x03(\x0e\x32\r.EUpdaterType\"\xb6\x01\n\x1b\x43MsgSystemUpdateApplyResult\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32\r.EUpdaterType:\x16k_EUpdaterType_Invalid\x12\x12\n\x07\x65result\x18\x02 \x01(\r:\x01\x32\x12&\n\x17requires_client_restart\x18\x03 \x01(\x08:\x05\x66\x61lse\x12&\n\x17requires_system_restart\x18\x04 \x01(\x08:\x05\x66\x61lse\"\xf4\x01\n\x15\x43MsgSystemUpdateState\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32\x0e.EUpdaterState:\x17k_EUpdaterState_Invalid\x12+\n\x08progress\x18\x02 \x01(\x0b\x32\x19.CMsgSystemUpdateProgress\x12:\n\x14update_check_results\x18\x03 \x03(\x0b\x32\x1c.CMsgSystemUpdateCheckResult\x12:\n\x14update_apply_results\x18\x04 \x03(\x0b\x32\x1c.CMsgSystemUpdateApplyResult\"&\n\x15\x43MsgAchievementChange\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"\\\n\x0c\x43MsgCellList\x12!\n\x05\x63\x65lls\x18\x01 \x03(\x0b\x32\x12.CMsgCellList.Cell\x1a)\n\x04\x43\x65ll\x12\x0f\n\x07\x63\x65ll_id\x18\x01 \x01(\r\x12\x10\n\x08loc_name\x18\x02 \x01(\t\"\x8e\x03\n\x10\x43MsgShortcutInfo\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0b\n\x03\x65xe\x18\x02 \x01(\t\x12\x11\n\tstart_dir\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x06 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x07 \x01(\t\x12\x16\n\x0eoverride_appid\x18\x08 \x01(\r\x12\x15\n\rflatpak_appid\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12\x11\n\tis_remote\x18\x0b \x01(\x08\x12\x11\n\tis_hidden\x18\x0c \x01(\x08\x12\x14\n\x0cis_temporary\x18\r \x01(\x08\x12\x11\n\tis_openvr\x18\x0e \x01(\x08\x12\x1c\n\x14\x61llow_desktop_config\x18\x0f \x01(\x08\x12\x15\n\rallow_overlay\x18\x10 \x01(\x08\x12\x1b\n\x13rt_last_played_time\x18\x11 \x01(\r\x12\x1a\n\x12is_devkit_shortcut\x18\x12 \x01(\x08\x12\x15\n\rdevkit_gameid\x18\x13 \x01(\t\"$\n\x12\x43MsgShortcutAppIds\x12\x0e\n\x06\x61ppids\x18\x01 \x03(\r*\x96\x02\n\x1c\x45\x43loudPendingRemoteOperation\x12&\n\"k_ECloudPendingRemoteOperationNone\x10\x00\x12\x32\n.k_ECloudPendingRemoteOperationAppSessionActive\x10\x01\x12\x32\n.k_ECloudPendingRemoteOperationUploadInProgress\x10\x02\x12/\n+k_ECloudPendingRemoteOperationUploadPending\x10\x03\x12\x35\n1k_ECloudPendingRemoteOperationAppSessionSuspended\x10\x04*\x9f\x0c\n\x18\x45SteamDeckKeyboardLayout\x12%\n!k_ESteamDeckKeyboardLayout_QWERTY\x10\x00\x12(\n$k_ESteamDeckKeyboardLayout_Bulgarian\x10\x01\x12\x31\n-k_ESteamDeckKeyboardLayout_Chinese_Simplified\x10\x02\x12\x32\n.k_ESteamDeckKeyboardLayout_Chinese_Traditional\x10\x03\x12$\n k_ESteamDeckKeyboardLayout_Czech\x10\x04\x12%\n!k_ESteamDeckKeyboardLayout_Danish\x10\x05\x12&\n\"k_ESteamDeckKeyboardLayout_Finnish\x10\x06\x12%\n!k_ESteamDeckKeyboardLayout_French\x10\x07\x12%\n!k_ESteamDeckKeyboardLayout_German\x10\x08\x12$\n k_ESteamDeckKeyboardLayout_Greek\x10\t\x12(\n$k_ESteamDeckKeyboardLayout_Hungarian\x10\n\x12&\n\"k_ESteamDeckKeyboardLayout_Italian\x10\x0b\x12\'\n#k_ESteamDeckKeyboardLayout_Japanese\x10\x0c\x12%\n!k_ESteamDeckKeyboardLayout_Korean\x10\r\x12(\n$k_ESteamDeckKeyboardLayout_Norwegian\x10\x0e\x12%\n!k_ESteamDeckKeyboardLayout_Polish\x10\x0f\x12)\n%k_ESteamDeckKeyboardLayout_Portuguese\x10\x10\x12\'\n#k_ESteamDeckKeyboardLayout_Romanian\x10\x11\x12&\n\"k_ESteamDeckKeyboardLayout_Russian\x10\x12\x12&\n\"k_ESteamDeckKeyboardLayout_Spanish\x10\x13\x12&\n\"k_ESteamDeckKeyboardLayout_Swedish\x10\x14\x12#\n\x1fk_ESteamDeckKeyboardLayout_Thai\x10\x15\x12(\n$k_ESteamDeckKeyboardLayout_Turkish_F\x10\x16\x12(\n$k_ESteamDeckKeyboardLayout_Turkish_Q\x10\x17\x12(\n$k_ESteamDeckKeyboardLayout_Ukrainian\x10\x18\x12)\n%k_ESteamDeckKeyboardLayout_Vietnamese\x10\x19\x12\x33\n/k_ESteamDeckKeyboardLayout_QWERTY_International\x10\x1a\x12%\n!k_ESteamDeckKeyboardLayout_Dvorak\x10\x1b\x12&\n\"k_ESteamDeckKeyboardLayout_Colemak\x10\x1c\x12=\n9k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic_Traditional\x10\x1d\x12\x31\n-k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic\x10\x1e\x12;\n7k_ESteamDeckKeyboardLayout_Chinese_Traditional_Bopomofo\x10\x1f\x12:\n6k_ESteamDeckKeyboardLayout_Chinese_Traditional_Cangjie\x10 \x12,\n(k_ESteamDeckKeyboardLayout_Japanese_Kana\x10!\x12\x38\n4k_ESteamDeckKeyboardLayout_Chinese_Traditional_Quick\x10\"B\x05H\x01\x90\x01\x00'
  ,
  dependencies=[enums__pb2.DESCRIPTOR,])

_ECLOUDPENDINGREMOTEOPERATION = _descriptor.EnumDescriptor(
  name='ECloudPendingRemoteOperation',
  full_name='ECloudPendingRemoteOperation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ECloudPendingRemoteOperationNone', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ECloudPendingRemoteOperationAppSessionActive', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ECloudPendingRemoteOperationUploadInProgress', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ECloudPendingRemoteOperationUploadPending', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ECloudPendingRemoteOperationAppSessionSuspended', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11733,
  serialized_end=12011,
)
_sym_db.RegisterEnumDescriptor(_ECLOUDPENDINGREMOTEOPERATION)

ECloudPendingRemoteOperation = enum_type_wrapper.EnumTypeWrapper(_ECLOUDPENDINGREMOTEOPERATION)
_ESTEAMDECKKEYBOARDLAYOUT = _descriptor.EnumDescriptor(
  name='ESteamDeckKeyboardLayout',
  full_name='ESteamDeckKeyboardLayout',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_QWERTY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Bulgarian', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Chinese_Simplified', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Chinese_Traditional', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Czech', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Danish', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Finnish', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_French', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_German', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Greek', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Hungarian', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Italian', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Japanese', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Korean', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Norwegian', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Polish', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Portuguese', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Romanian', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Russian', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Spanish', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Swedish', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Thai', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Turkish_F', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Turkish_Q', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Ukrainian', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Vietnamese', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_QWERTY_International', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Dvorak', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Colemak', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic_Traditional', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Chinese_Traditional_Bopomofo', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Chinese_Traditional_Cangjie', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Japanese_Kana', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_ESteamDeckKeyboardLayout_Chinese_Traditional_Quick', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12014,
  serialized_end=13581,
)
_sym_db.RegisterEnumDescriptor(_ESTEAMDECKKEYBOARDLAYOUT)

ESteamDeckKeyboardLayout = enum_type_wrapper.EnumTypeWrapper(_ESTEAMDECKKEYBOARDLAYOUT)
k_ECloudPendingRemoteOperationNone = 0
k_ECloudPendingRemoteOperationAppSessionActive = 1
k_ECloudPendingRemoteOperationUploadInProgress = 2
k_ECloudPendingRemoteOperationUploadPending = 3
k_ECloudPendingRemoteOperationAppSessionSuspended = 4
k_ESteamDeckKeyboardLayout_QWERTY = 0
k_ESteamDeckKeyboardLayout_Bulgarian = 1
k_ESteamDeckKeyboardLayout_Chinese_Simplified = 2
k_ESteamDeckKeyboardLayout_Chinese_Traditional = 3
k_ESteamDeckKeyboardLayout_Czech = 4
k_ESteamDeckKeyboardLayout_Danish = 5
k_ESteamDeckKeyboardLayout_Finnish = 6
k_ESteamDeckKeyboardLayout_French = 7
k_ESteamDeckKeyboardLayout_German = 8
k_ESteamDeckKeyboardLayout_Greek = 9
k_ESteamDeckKeyboardLayout_Hungarian = 10
k_ESteamDeckKeyboardLayout_Italian = 11
k_ESteamDeckKeyboardLayout_Japanese = 12
k_ESteamDeckKeyboardLayout_Korean = 13
k_ESteamDeckKeyboardLayout_Norwegian = 14
k_ESteamDeckKeyboardLayout_Polish = 15
k_ESteamDeckKeyboardLayout_Portuguese = 16
k_ESteamDeckKeyboardLayout_Romanian = 17
k_ESteamDeckKeyboardLayout_Russian = 18
k_ESteamDeckKeyboardLayout_Spanish = 19
k_ESteamDeckKeyboardLayout_Swedish = 20
k_ESteamDeckKeyboardLayout_Thai = 21
k_ESteamDeckKeyboardLayout_Turkish_F = 22
k_ESteamDeckKeyboardLayout_Turkish_Q = 23
k_ESteamDeckKeyboardLayout_Ukrainian = 24
k_ESteamDeckKeyboardLayout_Vietnamese = 25
k_ESteamDeckKeyboardLayout_QWERTY_International = 26
k_ESteamDeckKeyboardLayout_Dvorak = 27
k_ESteamDeckKeyboardLayout_Colemak = 28
k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic_Traditional = 29
k_ESteamDeckKeyboardLayout_Bulgarian_Phonetic = 30
k_ESteamDeckKeyboardLayout_Chinese_Traditional_Bopomofo = 31
k_ESteamDeckKeyboardLayout_Chinese_Traditional_Cangjie = 32
k_ESteamDeckKeyboardLayout_Japanese_Kana = 33
k_ESteamDeckKeyboardLayout_Chinese_Traditional_Quick = 34



_STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES = _descriptor.Descriptor(
  name='SteamMessagesClientIClientForcedEnumDependencies',
  full_name='SteamMessagesClientIClientForcedEnumDependencies',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='a', full_name='SteamMessagesClientIClientForcedEnumDependencies.a', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='SteamMessagesClientIClientForcedEnumDependencies.b', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='c', full_name='SteamMessagesClientIClientForcedEnumDependencies.c', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='d', full_name='SteamMessagesClientIClientForcedEnumDependencies.d', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=383,
)


_CMSGNETWORKDEVICEIP4ADDRESS = _descriptor.Descriptor(
  name='CMsgNetworkDeviceIP4Address',
  full_name='CMsgNetworkDeviceIP4Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgNetworkDeviceIP4Address.ip', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='netmask', full_name='CMsgNetworkDeviceIP4Address.netmask', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=446,
)


_CMSGNETWORKDEVICEIP4CONFIG = _descriptor.Descriptor(
  name='CMsgNetworkDeviceIP4Config',
  full_name='CMsgNetworkDeviceIP4Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='CMsgNetworkDeviceIP4Config.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_ip', full_name='CMsgNetworkDeviceIP4Config.dns_ip', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway_ip', full_name='CMsgNetworkDeviceIP4Config.gateway_ip', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dhcp_enabled', full_name='CMsgNetworkDeviceIP4Config.is_dhcp_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_default_route', full_name='CMsgNetworkDeviceIP4Config.is_default_route', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='CMsgNetworkDeviceIP4Config.is_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=640,
)


_CMSGNETWORKDEVICEIP6ADDRESS = _descriptor.Descriptor(
  name='CMsgNetworkDeviceIP6Address',
  full_name='CMsgNetworkDeviceIP6Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='CMsgNetworkDeviceIP6Address.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=642,
  serialized_end=683,
)


_CMSGNETWORKDEVICEIP6CONFIG = _descriptor.Descriptor(
  name='CMsgNetworkDeviceIP6Config',
  full_name='CMsgNetworkDeviceIP6Config',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='CMsgNetworkDeviceIP6Config.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_ip', full_name='CMsgNetworkDeviceIP6Config.dns_ip', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway_ip', full_name='CMsgNetworkDeviceIP6Config.gateway_ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dhcp_enabled', full_name='CMsgNetworkDeviceIP6Config.is_dhcp_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_default_route', full_name='CMsgNetworkDeviceIP6Config.is_default_route', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='CMsgNetworkDeviceIP6Config.is_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=877,
)


_CMSGNETWORKDEVICESDATA_DEVICE_WIRED = _descriptor.Descriptor(
  name='Wired',
  full_name='CMsgNetworkDevicesData.Device.Wired',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_cable_present', full_name='CMsgNetworkDevicesData.Device.Wired.is_cable_present', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_mbit', full_name='CMsgNetworkDevicesData.Device.Wired.speed_mbit', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friendly_name', full_name='CMsgNetworkDevicesData.Device.Wired.friendly_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1313,
  serialized_end=1396,
)

_CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP = _descriptor.Descriptor(
  name='AP',
  full_name='CMsgNetworkDevicesData.Device.Wireless.AP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estrength', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.estrength', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssid', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.ssid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_active', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.is_active', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_autoconnect', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.is_autoconnect', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esecurity', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.esecurity', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_name', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.user_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.password', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strength_raw', full_name='CMsgNetworkDevicesData.Device.Wireless.AP.strength_raw', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1498,
  serialized_end=1671,
)

_CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS = _descriptor.Descriptor(
  name='Wireless',
  full_name='CMsgNetworkDevicesData.Device.Wireless',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aps', full_name='CMsgNetworkDevicesData.Device.Wireless.aps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esecurity_supported', full_name='CMsgNetworkDevicesData.Device.Wireless.esecurity_supported', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1399,
  serialized_end=1671,
)

_CMSGNETWORKDEVICESDATA_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='CMsgNetworkDevicesData.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgNetworkDevicesData.Device.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etype', full_name='CMsgNetworkDevicesData.Device.etype', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estate', full_name='CMsgNetworkDevicesData.Device.estate', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='CMsgNetworkDevicesData.Device.mac', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='CMsgNetworkDevicesData.Device.vendor', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='CMsgNetworkDevicesData.Device.product', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip4', full_name='CMsgNetworkDevicesData.Device.ip4', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip6', full_name='CMsgNetworkDevicesData.Device.ip6', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wired', full_name='CMsgNetworkDevicesData.Device.wired', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wireless', full_name='CMsgNetworkDevicesData.Device.wireless', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGNETWORKDEVICESDATA_DEVICE_WIRED, _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1671,
)

_CMSGNETWORKDEVICESDATA = _descriptor.Descriptor(
  name='CMsgNetworkDevicesData',
  full_name='CMsgNetworkDevicesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='CMsgNetworkDevicesData.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wifi_enabled', full_name='CMsgNetworkDevicesData.is_wifi_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wifi_scanning_enabled', full_name='CMsgNetworkDevicesData.is_wifi_scanning_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGNETWORKDEVICESDATA_DEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=880,
  serialized_end=1671,
)


_CMSGNETWORKDEVICECONNECT_KNOWNAP = _descriptor.Descriptor(
  name='KnownAP',
  full_name='CMsgNetworkDeviceConnect.KnownAP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ap_id', full_name='CMsgNetworkDeviceConnect.KnownAP.ap_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1980,
  serialized_end=2004,
)

_CMSGNETWORKDEVICECONNECT_CUSTOMAP = _descriptor.Descriptor(
  name='CustomAP',
  full_name='CMsgNetworkDeviceConnect.CustomAP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ssid', full_name='CMsgNetworkDeviceConnect.CustomAP.ssid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='esecurity', full_name='CMsgNetworkDeviceConnect.CustomAP.esecurity', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2006,
  serialized_end=2049,
)

_CMSGNETWORKDEVICECONNECT_CREDENTIALS = _descriptor.Descriptor(
  name='Credentials',
  full_name='CMsgNetworkDeviceConnect.Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='username', full_name='CMsgNetworkDeviceConnect.Credentials.username', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='CMsgNetworkDeviceConnect.Credentials.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2051,
  serialized_end=2100,
)

_CMSGNETWORKDEVICECONNECT = _descriptor.Descriptor(
  name='CMsgNetworkDeviceConnect',
  full_name='CMsgNetworkDeviceConnect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='CMsgNetworkDeviceConnect.device_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='credentials', full_name='CMsgNetworkDeviceConnect.credentials', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip4', full_name='CMsgNetworkDeviceConnect.ip4', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip6', full_name='CMsgNetworkDeviceConnect.ip6', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ap_known', full_name='CMsgNetworkDeviceConnect.ap_known', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ap_custom', full_name='CMsgNetworkDeviceConnect.ap_custom', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGNETWORKDEVICECONNECT_KNOWNAP, _CMSGNETWORKDEVICECONNECT_CUSTOMAP, _CMSGNETWORKDEVICECONNECT_CREDENTIALS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ap_info', full_name='CMsgNetworkDeviceConnect.ap_info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1674,
  serialized_end=2111,
)


_CMSGSTORAGEDEVICESDATA_DRIVE = _descriptor.Descriptor(
  name='Drive',
  full_name='CMsgStorageDevicesData.Drive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgStorageDevicesData.Drive.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='CMsgStorageDevicesData.Drive.model', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='CMsgStorageDevicesData.Drive.vendor', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial', full_name='CMsgStorageDevicesData.Drive.serial', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_ejectable', full_name='CMsgStorageDevicesData.Drive.is_ejectable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='CMsgStorageDevicesData.Drive.size_bytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2277,
  serialized_end=2388,
)

_CMSGSTORAGEDEVICESDATA_BLOCKDEVICE = _descriptor.Descriptor(
  name='BlockDevice',
  full_name='CMsgStorageDevicesData.BlockDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgStorageDevicesData.BlockDevice.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drive_id', full_name='CMsgStorageDevicesData.BlockDevice.drive_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='CMsgStorageDevicesData.BlockDevice.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='friendly_path', full_name='CMsgStorageDevicesData.BlockDevice.friendly_path', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='CMsgStorageDevicesData.BlockDevice.label', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_bytes', full_name='CMsgStorageDevicesData.BlockDevice.size_bytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_formattable', full_name='CMsgStorageDevicesData.BlockDevice.is_formattable', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_read_only', full_name='CMsgStorageDevicesData.BlockDevice.is_read_only', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_root_device', full_name='CMsgStorageDevicesData.BlockDevice.is_root_device', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='CMsgStorageDevicesData.BlockDevice.content_type', index=9,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_type', full_name='CMsgStorageDevicesData.BlockDevice.filesystem_type', index=10,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mount_path', full_name='CMsgStorageDevicesData.BlockDevice.mount_path', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2391,
  serialized_end=2781,
)

_CMSGSTORAGEDEVICESDATA = _descriptor.Descriptor(
  name='CMsgStorageDevicesData',
  full_name='CMsgStorageDevicesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drives', full_name='CMsgStorageDevicesData.drives', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_devices', full_name='CMsgStorageDevicesData.block_devices', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_unmount_supported', full_name='CMsgStorageDevicesData.is_unmount_supported', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSTORAGEDEVICESDATA_DRIVE, _CMSGSTORAGEDEVICESDATA_BLOCKDEVICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2114,
  serialized_end=2781,
)


_CCLOUD_PENDINGREMOTEOPERATION = _descriptor.Descriptor(
  name='CCloud_PendingRemoteOperation',
  full_name='CCloud_PendingRemoteOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation', full_name='CCloud_PendingRemoteOperation.operation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CCloud_PendingRemoteOperation.machine_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_id', full_name='CCloud_PendingRemoteOperation.client_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last_updated', full_name='CCloud_PendingRemoteOperation.time_last_updated', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2784,
  serialized_end=2969,
)


_CMSGCLOUDPENDINGREMOTEOPERATIONS = _descriptor.Descriptor(
  name='CMsgCloudPendingRemoteOperations',
  full_name='CMsgCloudPendingRemoteOperations',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='CMsgCloudPendingRemoteOperations.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2971,
  serialized_end=3057,
)


_CMSGBLUETOOTHDEVICESDATA_ADAPTER = _descriptor.Descriptor(
  name='Adapter',
  full_name='CMsgBluetoothDevicesData.Adapter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgBluetoothDevicesData.Adapter.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='CMsgBluetoothDevicesData.Adapter.mac', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgBluetoothDevicesData.Adapter.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='CMsgBluetoothDevicesData.Adapter.is_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_discovering', full_name='CMsgBluetoothDevicesData.Adapter.is_discovering', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3244,
  serialized_end=3339,
)

_CMSGBLUETOOTHDEVICESDATA_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='CMsgBluetoothDevicesData.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgBluetoothDevicesData.Device.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adapter_id', full_name='CMsgBluetoothDevicesData.Device.adapter_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etype', full_name='CMsgBluetoothDevicesData.Device.etype', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='CMsgBluetoothDevicesData.Device.mac', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgBluetoothDevicesData.Device.name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_connected', full_name='CMsgBluetoothDevicesData.Device.is_connected', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_paired', full_name='CMsgBluetoothDevicesData.Device.is_paired', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strength_raw', full_name='CMsgBluetoothDevicesData.Device.strength_raw', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3342,
  serialized_end=3547,
)

_CMSGBLUETOOTHDEVICESDATA_MANAGER = _descriptor.Descriptor(
  name='Manager',
  full_name='CMsgBluetoothDevicesData.Manager',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_bluetooth_enabled', full_name='CMsgBluetoothDevicesData.Manager.is_bluetooth_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3549,
  serialized_end=3588,
)

_CMSGBLUETOOTHDEVICESDATA = _descriptor.Descriptor(
  name='CMsgBluetoothDevicesData',
  full_name='CMsgBluetoothDevicesData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='adapters', full_name='CMsgBluetoothDevicesData.adapters', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devices', full_name='CMsgBluetoothDevicesData.devices', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manager', full_name='CMsgBluetoothDevicesData.manager', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGBLUETOOTHDEVICESDATA_ADAPTER, _CMSGBLUETOOTHDEVICESDATA_DEVICE, _CMSGBLUETOOTHDEVICESDATA_MANAGER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3060,
  serialized_end=3588,
)


_CMSGSYSTEMPERFDIAGNOSTICENTRY = _descriptor.Descriptor(
  name='CMsgSystemPerfDiagnosticEntry',
  full_name='CMsgSystemPerfDiagnosticEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgSystemPerfDiagnosticEntry.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='CMsgSystemPerfDiagnosticEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3590,
  serialized_end=3650,
)


_CMSGSYSTEMPERFNETWORKINTERFACE = _descriptor.Descriptor(
  name='CMsgSystemPerfNetworkInterface',
  full_name='CMsgSystemPerfNetworkInterface',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgSystemPerfNetworkInterface.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgSystemPerfNetworkInterface.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes_total', full_name='CMsgSystemPerfNetworkInterface.tx_bytes_total', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bytes_total', full_name='CMsgSystemPerfNetworkInterface.rx_bytes_total', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_bytes_per_sec', full_name='CMsgSystemPerfNetworkInterface.tx_bytes_per_sec', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rx_bytes_per_sec', full_name='CMsgSystemPerfNetworkInterface.rx_bytes_per_sec', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3653,
  serialized_end=3818,
)


_CMSGSYSTEMPERFDIAGNOSTICINFO = _descriptor.Descriptor(
  name='CMsgSystemPerfDiagnosticInfo',
  full_name='CMsgSystemPerfDiagnosticInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgSystemPerfDiagnosticInfo.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interfaces', full_name='CMsgSystemPerfDiagnosticInfo.interfaces', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='battery_temp_c', full_name='CMsgSystemPerfDiagnosticInfo.battery_temp_c', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3821,
  serialized_end=3977,
)


_CMSGSYSTEMPERFLIMITS = _descriptor.Descriptor(
  name='CMsgSystemPerfLimits',
  full_name='CMsgSystemPerfLimits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpu_governor_manual_min_mhz', full_name='CMsgSystemPerfLimits.cpu_governor_manual_min_mhz', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_governor_manual_max_mhz', full_name='CMsgSystemPerfLimits.cpu_governor_manual_max_mhz', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsr_sharpness_min', full_name='CMsgSystemPerfLimits.fsr_sharpness_min', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsr_sharpness_max', full_name='CMsgSystemPerfLimits.fsr_sharpness_max', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_performance_manual_min_mhz', full_name='CMsgSystemPerfLimits.gpu_performance_manual_min_mhz', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_performance_manual_max_mhz', full_name='CMsgSystemPerfLimits.gpu_performance_manual_max_mhz', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_overlay_is_standalone', full_name='CMsgSystemPerfLimits.perf_overlay_is_standalone', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dynamic_vrs_available', full_name='CMsgSystemPerfLimits.is_dynamic_vrs_available', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_manual_display_refresh_rate_available', full_name='CMsgSystemPerfLimits.is_manual_display_refresh_rate_available', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_performance_levels_available', full_name='CMsgSystemPerfLimits.gpu_performance_levels_available', index=9,
      number=10, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_refresh_manual_hz_min', full_name='CMsgSystemPerfLimits.display_refresh_manual_hz_min', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_refresh_manual_hz_max', full_name='CMsgSystemPerfLimits.display_refresh_manual_hz_max', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fps_limit_options', full_name='CMsgSystemPerfLimits.fps_limit_options', index=12,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tdp_limit_min', full_name='CMsgSystemPerfLimits.tdp_limit_min', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tdp_limit_max', full_name='CMsgSystemPerfLimits.tdp_limit_max', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_nis_supported', full_name='CMsgSystemPerfLimits.is_nis_supported', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nis_sharpness_min', full_name='CMsgSystemPerfLimits.nis_sharpness_min', index=16,
      number=17, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nis_sharpness_max', full_name='CMsgSystemPerfLimits.nis_sharpness_max', index=17,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3980,
  serialized_end=4626,
)


_CMSGSYSTEMPERFSETTINGSGLOBAL = _descriptor.Descriptor(
  name='CMsgSystemPerfSettingsGlobal',
  full_name='CMsgSystemPerfSettingsGlobal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diagnostic_update_rate', full_name='CMsgSystemPerfSettingsGlobal.diagnostic_update_rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_trace_service_state', full_name='CMsgSystemPerfSettingsGlobal.system_trace_service_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='graphics_profiling_service_state', full_name='CMsgSystemPerfSettingsGlobal.graphics_profiling_service_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_overlay_service_state', full_name='CMsgSystemPerfSettingsGlobal.perf_overlay_service_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_overlay_level', full_name='CMsgSystemPerfSettingsGlobal.perf_overlay_level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_show_perf_overlay_over_steam_enabled', full_name='CMsgSystemPerfSettingsGlobal.is_show_perf_overlay_over_steam_enabled', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_advanced_settings_enabled', full_name='CMsgSystemPerfSettingsGlobal.is_advanced_settings_enabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4629,
  serialized_end=5155,
)


_CMSGSYSTEMPERFSETTINGSPERAPP = _descriptor.Descriptor(
  name='CMsgSystemPerfSettingsPerApp',
  full_name='CMsgSystemPerfSettingsPerApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_performance_manual_mhz', full_name='CMsgSystemPerfSettingsPerApp.gpu_performance_manual_mhz', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fps_limit', full_name='CMsgSystemPerfSettingsPerApp.fps_limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_variable_resolution_enabled', full_name='CMsgSystemPerfSettingsPerApp.is_variable_resolution_enabled', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dynamic_refresh_rate_enabled', full_name='CMsgSystemPerfSettingsPerApp.is_dynamic_refresh_rate_enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tdp_limit', full_name='CMsgSystemPerfSettingsPerApp.tdp_limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_governor', full_name='CMsgSystemPerfSettingsPerApp.cpu_governor', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_governor_manual_mhz', full_name='CMsgSystemPerfSettingsPerApp.cpu_governor_manual_mhz', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaling_filter', full_name='CMsgSystemPerfSettingsPerApp.scaling_filter', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsr_sharpness', full_name='CMsgSystemPerfSettingsPerApp.fsr_sharpness', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_fps_limit_enabled', full_name='CMsgSystemPerfSettingsPerApp.is_fps_limit_enabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_tdp_limit_enabled', full_name='CMsgSystemPerfSettingsPerApp.is_tdp_limit_enabled', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_low_latency_mode_enabled', full_name='CMsgSystemPerfSettingsPerApp.is_low_latency_mode_enabled', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_refresh_manual_hz', full_name='CMsgSystemPerfSettingsPerApp.display_refresh_manual_hz', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_game_perf_profile_enabled', full_name='CMsgSystemPerfSettingsPerApp.is_game_perf_profile_enabled', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_performance_level', full_name='CMsgSystemPerfSettingsPerApp.gpu_performance_level', index=14,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nis_sharpness', full_name='CMsgSystemPerfSettingsPerApp.nis_sharpness', index=15,
      number=16, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5158,
  serialized_end=5763,
)


_CMSGSYSTEMPERFSETTINGS = _descriptor.Descriptor(
  name='CMsgSystemPerfSettings',
  full_name='CMsgSystemPerfSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='global', full_name='CMsgSystemPerfSettings.global', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='per_app', full_name='CMsgSystemPerfSettings.per_app', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5765,
  serialized_end=5884,
)


_CMSGSYSTEMPERFSETTINGSV1 = _descriptor.Descriptor(
  name='CMsgSystemPerfSettingsV1',
  full_name='CMsgSystemPerfSettingsV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diagnostic_update_rate', full_name='CMsgSystemPerfSettingsV1.diagnostic_update_rate', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system_trace_service_state', full_name='CMsgSystemPerfSettingsV1.system_trace_service_state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='graphics_profiling_service_state', full_name='CMsgSystemPerfSettingsV1.graphics_profiling_service_state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_overlay_service_state', full_name='CMsgSystemPerfSettingsV1.perf_overlay_service_state', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perf_overlay_level', full_name='CMsgSystemPerfSettingsV1.perf_overlay_level', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_performance_level', full_name='CMsgSystemPerfSettingsV1.gpu_performance_level', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_performance_manual_mhz', full_name='CMsgSystemPerfSettingsV1.gpu_performance_manual_mhz', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fps_limit', full_name='CMsgSystemPerfSettingsV1.fps_limit', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_variable_resolution_enabled', full_name='CMsgSystemPerfSettingsV1.is_variable_resolution_enabled', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_dynamic_refresh_rate_enabled', full_name='CMsgSystemPerfSettingsV1.is_dynamic_refresh_rate_enabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tdp_limit', full_name='CMsgSystemPerfSettingsV1.tdp_limit', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_governor', full_name='CMsgSystemPerfSettingsV1.cpu_governor', index=11,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cpu_governor_manual_mhz', full_name='CMsgSystemPerfSettingsV1.cpu_governor_manual_mhz', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaling_filter', full_name='CMsgSystemPerfSettingsV1.scaling_filter', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsr_sharpness', full_name='CMsgSystemPerfSettingsV1.fsr_sharpness', index=14,
      number=15, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_fps_limit_enabled', full_name='CMsgSystemPerfSettingsV1.is_fps_limit_enabled', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_tdp_limit_enabled', full_name='CMsgSystemPerfSettingsV1.is_tdp_limit_enabled', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_show_perf_overlay_over_steam_enabled', full_name='CMsgSystemPerfSettingsV1.is_show_perf_overlay_over_steam_enabled', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_low_latency_mode_enabled', full_name='CMsgSystemPerfSettingsV1.is_low_latency_mode_enabled', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_refresh_manual_hz', full_name='CMsgSystemPerfSettingsV1.display_refresh_manual_hz', index=19,
      number=20, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_game_perf_profile_enabled', full_name='CMsgSystemPerfSettingsV1.is_game_perf_profile_enabled', index=20,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5887,
  serialized_end=6923,
)


_CMSGSYSTEMPERFSTATE = _descriptor.Descriptor(
  name='CMsgSystemPerfState',
  full_name='CMsgSystemPerfState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limits', full_name='CMsgSystemPerfState.limits', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='CMsgSystemPerfState.settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_game_id', full_name='CMsgSystemPerfState.current_game_id', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_profile_game_id', full_name='CMsgSystemPerfState.active_profile_game_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6926,
  serialized_end=7086,
)


_CMSGSYSTEMPERFUPDATESETTINGS = _descriptor.Descriptor(
  name='CMsgSystemPerfUpdateSettings',
  full_name='CMsgSystemPerfUpdateSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gameid', full_name='CMsgSystemPerfUpdateSettings.gameid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reset_to_default', full_name='CMsgSystemPerfUpdateSettings.reset_to_default', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings_delta', full_name='CMsgSystemPerfUpdateSettings.settings_delta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='update', full_name='CMsgSystemPerfUpdateSettings.update',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7089,
  serialized_end=7224,
)


_CMSGSYSTEMDOCKUPDATESTATE = _descriptor.Descriptor(
  name='CMsgSystemDockUpdateState',
  full_name='CMsgSystemDockUpdateState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgSystemDockUpdateState.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_last_checked', full_name='CMsgSystemDockUpdateState.rtime_last_checked', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_current', full_name='CMsgSystemDockUpdateState.version_current', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version_available', full_name='CMsgSystemDockUpdateState.version_available', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage_progress', full_name='CMsgSystemDockUpdateState.stage_progress', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_estimated_completion', full_name='CMsgSystemDockUpdateState.rtime_estimated_completion', index=5,
      number=6, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7227,
  serialized_end=7450,
)


_CMSGSYSTEMDOCKSTATE = _descriptor.Descriptor(
  name='CMsgSystemDockState',
  full_name='CMsgSystemDockState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_state', full_name='CMsgSystemDockState.update_state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7452,
  serialized_end=7523,
)


_CMSGSYSTEMDOCKUPDATEFIRMWARE = _descriptor.Descriptor(
  name='CMsgSystemDockUpdateFirmware',
  full_name='CMsgSystemDockUpdateFirmware',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='check_only', full_name='CMsgSystemDockUpdateFirmware.check_only', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7525,
  serialized_end=7575,
)


_CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY = _descriptor.Descriptor(
  name='ChannelEntry',
  full_name='CMsgSystemAudioVolume.ChannelEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='echannel', full_name='CMsgSystemAudioVolume.ChannelEntry.echannel', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='CMsgSystemAudioVolume.ChannelEntry.volume', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7675,
  serialized_end=7775,
)

_CMSGSYSTEMAUDIOVOLUME = _descriptor.Descriptor(
  name='CMsgSystemAudioVolume',
  full_name='CMsgSystemAudioVolume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgSystemAudioVolume.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_muted', full_name='CMsgSystemAudioVolume.is_muted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7578,
  serialized_end=7775,
)


_CMSGSYSTEMAUDIOMANAGEROBJECT = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerObject',
  full_name='CMsgSystemAudioManagerObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='CMsgSystemAudioManagerObject.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_last_update', full_name='CMsgSystemAudioManagerObject.rtime_last_update', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7777,
  serialized_end=7846,
)


_CMSGSYSTEMAUDIOMANAGERDEVICE = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerDevice',
  full_name='CMsgSystemAudioManagerDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='CMsgSystemAudioManagerDevice.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgSystemAudioManagerDevice.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nick', full_name='CMsgSystemAudioManagerDevice.nick', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgSystemAudioManagerDevice.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api', full_name='CMsgSystemAudioManagerDevice.api', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7849,
  serialized_end=7986,
)


_CMSGSYSTEMAUDIOMANAGERNODE = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerNode',
  full_name='CMsgSystemAudioManagerNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='CMsgSystemAudioManagerNode.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_id', full_name='CMsgSystemAudioManagerNode.device_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgSystemAudioManagerNode.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nick', full_name='CMsgSystemAudioManagerNode.nick', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgSystemAudioManagerNode.description', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edirection', full_name='CMsgSystemAudioManagerNode.edirection', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='CMsgSystemAudioManagerNode.volume', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7989,
  serialized_end=8246,
)


_CMSGSYSTEMAUDIOMANAGERPORT = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerPort',
  full_name='CMsgSystemAudioManagerPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='CMsgSystemAudioManagerPort.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='CMsgSystemAudioManagerPort.node_id', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgSystemAudioManagerPort.name', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alias', full_name='CMsgSystemAudioManagerPort.alias', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='etype', full_name='CMsgSystemAudioManagerPort.etype', index=4,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edirection', full_name='CMsgSystemAudioManagerPort.edirection', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_physical', full_name='CMsgSystemAudioManagerPort.is_physical', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_terminal', full_name='CMsgSystemAudioManagerPort.is_terminal', index=7,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_control', full_name='CMsgSystemAudioManagerPort.is_control', index=8,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_monitor', full_name='CMsgSystemAudioManagerPort.is_monitor', index=9,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8249,
  serialized_end=8603,
)


_CMSGSYSTEMAUDIOMANAGERLINK = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerLink',
  full_name='CMsgSystemAudioManagerLink',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base', full_name='CMsgSystemAudioManagerLink.base', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_node_id', full_name='CMsgSystemAudioManagerLink.output_node_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='output_port_id', full_name='CMsgSystemAudioManagerLink.output_port_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_node_id', full_name='CMsgSystemAudioManagerLink.input_node_id', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='input_port_id', full_name='CMsgSystemAudioManagerLink.input_port_id', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8606,
  serialized_end=8773,
)


_CMSGSYSTEMAUDIOMANAGERSTATEHW = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerStateHW',
  full_name='CMsgSystemAudioManagerStateHW',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='CMsgSystemAudioManagerStateHW.devices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodes', full_name='CMsgSystemAudioManagerStateHW.nodes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='CMsgSystemAudioManagerStateHW.ports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='links', full_name='CMsgSystemAudioManagerStateHW.links', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8776,
  serialized_end=8987,
)


_CMSGSYSTEMAUDIOMANAGERSTATE = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerState',
  full_name='CMsgSystemAudioManagerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rtime_filter', full_name='CMsgSystemAudioManagerState.rtime_filter', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counter', full_name='CMsgSystemAudioManagerState.counter', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hw', full_name='CMsgSystemAudioManagerState.hw', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8989,
  serialized_end=9101,
)


_CMSGSYSTEMAUDIOMANAGERUPDATESOMETHING = _descriptor.Descriptor(
  name='CMsgSystemAudioManagerUpdateSomething',
  full_name='CMsgSystemAudioManagerUpdateSomething',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='counter', full_name='CMsgSystemAudioManagerUpdateSomething.counter', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9103,
  serialized_end=9159,
)


_CMSGSYSTEMMANAGERSETTINGS = _descriptor.Descriptor(
  name='CMsgSystemManagerSettings',
  full_name='CMsgSystemManagerSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='idle_backlight_dim_battery_seconds', full_name='CMsgSystemManagerSettings.idle_backlight_dim_battery_seconds', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_backlight_dim_ac_seconds', full_name='CMsgSystemManagerSettings.idle_backlight_dim_ac_seconds', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_suspend_battery_seconds', full_name='CMsgSystemManagerSettings.idle_suspend_battery_seconds', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_suspend_ac_seconds', full_name='CMsgSystemManagerSettings.idle_suspend_ac_seconds', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='idle_suspend_supressed', full_name='CMsgSystemManagerSettings.idle_suspend_supressed', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_adaptive_brightness_available', full_name='CMsgSystemManagerSettings.is_adaptive_brightness_available', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_adaptive_brightness_enabled', full_name='CMsgSystemManagerSettings.display_adaptive_brightness_enabled', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_display_colorprofile_available', full_name='CMsgSystemManagerSettings.is_display_colorprofile_available', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_colorprofile', full_name='CMsgSystemManagerSettings.display_colorprofile', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_enabled', full_name='CMsgSystemManagerSettings.display_nightmode_enabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_tintstrength', full_name='CMsgSystemManagerSettings.display_nightmode_tintstrength', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_maxhue', full_name='CMsgSystemManagerSettings.display_nightmode_maxhue', index=11,
      number=12, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_maxsat', full_name='CMsgSystemManagerSettings.display_nightmode_maxsat', index=12,
      number=13, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_uiexp', full_name='CMsgSystemManagerSettings.display_nightmode_uiexp', index=13,
      number=14, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_blend', full_name='CMsgSystemManagerSettings.display_nightmode_blend', index=14,
      number=15, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_reset', full_name='CMsgSystemManagerSettings.display_nightmode_reset', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_schedule_enabled', full_name='CMsgSystemManagerSettings.display_nightmode_schedule_enabled', index=16,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_schedule_starttime', full_name='CMsgSystemManagerSettings.display_nightmode_schedule_starttime', index=17,
      number=18, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_nightmode_schedule_endtime', full_name='CMsgSystemManagerSettings.display_nightmode_schedule_endtime', index=18,
      number=19, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_diagnostics_enabled', full_name='CMsgSystemManagerSettings.display_diagnostics_enabled', index=19,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='als_lux_latest', full_name='CMsgSystemManagerSettings.als_lux_latest', index=20,
      number=21, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='als_lux_median', full_name='CMsgSystemManagerSettings.als_lux_median', index=21,
      number=22, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_brightness_linear', full_name='CMsgSystemManagerSettings.display_brightness_linear', index=22,
      number=23, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_brightness_adaptivemin', full_name='CMsgSystemManagerSettings.display_brightness_adaptivemin', index=23,
      number=24, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display_brightness_adaptivemax', full_name='CMsgSystemManagerSettings.display_brightness_adaptivemax', index=24,
      number=25, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_wifi_powersave_enabled', full_name='CMsgSystemManagerSettings.is_wifi_powersave_enabled', index=25,
      number=26, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_fan_control_available', full_name='CMsgSystemManagerSettings.is_fan_control_available', index=26,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fan_control_mode', full_name='CMsgSystemManagerSettings.fan_control_mode', index=27,
      number=28, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9162,
  serialized_end=10303,
)


_CMSGSELECTOSBRANCHPARAMS = _descriptor.Descriptor(
  name='CMsgSelectOSBranchParams',
  full_name='CMsgSelectOSBranchParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='branch', full_name='CMsgSelectOSBranchParams.branch', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10305,
  serialized_end=10380,
)


_CMSGSYSTEMUPDATEPROGRESS = _descriptor.Descriptor(
  name='CMsgSystemUpdateProgress',
  full_name='CMsgSystemUpdateProgress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stage_progress', full_name='CMsgSystemUpdateProgress.stage_progress', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage_size_bytes', full_name='CMsgSystemUpdateProgress.stage_size_bytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_estimated_completion', full_name='CMsgSystemUpdateProgress.rtime_estimated_completion', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10382,
  serialized_end=10494,
)


_CMSGSYSTEMUPDATECHECKRESULT = _descriptor.Descriptor(
  name='CMsgSystemUpdateCheckResult',
  full_name='CMsgSystemUpdateCheckResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgSystemUpdateCheckResult.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgSystemUpdateCheckResult.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime_checked', full_name='CMsgSystemUpdateCheckResult.rtime_checked', index=2,
      number=3, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='CMsgSystemUpdateCheckResult.available', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='CMsgSystemUpdateCheckResult.version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10497,
  serialized_end=10658,
)


_CMSGSYSTEMUPDATEAPPLYPARAMS = _descriptor.Descriptor(
  name='CMsgSystemUpdateApplyParams',
  full_name='CMsgSystemUpdateApplyParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apply_types', full_name='CMsgSystemUpdateApplyParams.apply_types', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10660,
  serialized_end=10725,
)


_CMSGSYSTEMUPDATEAPPLYRESULT = _descriptor.Descriptor(
  name='CMsgSystemUpdateApplyResult',
  full_name='CMsgSystemUpdateApplyResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='CMsgSystemUpdateApplyResult.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgSystemUpdateApplyResult.eresult', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_client_restart', full_name='CMsgSystemUpdateApplyResult.requires_client_restart', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_system_restart', full_name='CMsgSystemUpdateApplyResult.requires_system_restart', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10728,
  serialized_end=10910,
)


_CMSGSYSTEMUPDATESTATE = _descriptor.Descriptor(
  name='CMsgSystemUpdateState',
  full_name='CMsgSystemUpdateState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='CMsgSystemUpdateState.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='progress', full_name='CMsgSystemUpdateState.progress', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_check_results', full_name='CMsgSystemUpdateState.update_check_results', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_apply_results', full_name='CMsgSystemUpdateState.update_apply_results', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10913,
  serialized_end=11157,
)


_CMSGACHIEVEMENTCHANGE = _descriptor.Descriptor(
  name='CMsgAchievementChange',
  full_name='CMsgAchievementChange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgAchievementChange.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11159,
  serialized_end=11197,
)


_CMSGCELLLIST_CELL = _descriptor.Descriptor(
  name='Cell',
  full_name='CMsgCellList.Cell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgCellList.Cell.cell_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loc_name', full_name='CMsgCellList.Cell.loc_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11250,
  serialized_end=11291,
)

_CMSGCELLLIST = _descriptor.Descriptor(
  name='CMsgCellList',
  full_name='CMsgCellList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cells', full_name='CMsgCellList.cells', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCELLLIST_CELL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11199,
  serialized_end=11291,
)


_CMSGSHORTCUTINFO = _descriptor.Descriptor(
  name='CMsgShortcutInfo',
  full_name='CMsgShortcutInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgShortcutInfo.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exe', full_name='CMsgShortcutInfo.exe', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_dir', full_name='CMsgShortcutInfo.start_dir', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='CMsgShortcutInfo.icon', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='CMsgShortcutInfo.path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='CMsgShortcutInfo.args', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_name', full_name='CMsgShortcutInfo.app_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_appid', full_name='CMsgShortcutInfo.override_appid', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatpak_appid', full_name='CMsgShortcutInfo.flatpak_appid', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='CMsgShortcutInfo.tags', index=9,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_remote', full_name='CMsgShortcutInfo.is_remote', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_hidden', full_name='CMsgShortcutInfo.is_hidden', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_temporary', full_name='CMsgShortcutInfo.is_temporary', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_openvr', full_name='CMsgShortcutInfo.is_openvr', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_desktop_config', full_name='CMsgShortcutInfo.allow_desktop_config', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_overlay', full_name='CMsgShortcutInfo.allow_overlay', index=15,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rt_last_played_time', full_name='CMsgShortcutInfo.rt_last_played_time', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_devkit_shortcut', full_name='CMsgShortcutInfo.is_devkit_shortcut', index=17,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devkit_gameid', full_name='CMsgShortcutInfo.devkit_gameid', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11294,
  serialized_end=11692,
)


_CMSGSHORTCUTAPPIDS = _descriptor.Descriptor(
  name='CMsgShortcutAppIds',
  full_name='CMsgShortcutAppIds',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appids', full_name='CMsgShortcutAppIds.appids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11694,
  serialized_end=11730,
)

_STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES.fields_by_name['a'].enum_type = enums__pb2._EBLUETOOTHDEVICETYPE
_STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES.fields_by_name['b'].enum_type = enums__pb2._ESTORAGEBLOCKCONTENTTYPE
_STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES.fields_by_name['c'].enum_type = enums__pb2._ESTORAGEBLOCKFILESYSTEMTYPE
_STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES.fields_by_name['d'].enum_type = enums__pb2._ESDCARDFORMATSTAGE
_CMSGNETWORKDEVICEIP4CONFIG.fields_by_name['addresses'].message_type = _CMSGNETWORKDEVICEIP4ADDRESS
_CMSGNETWORKDEVICEIP6CONFIG.fields_by_name['addresses'].message_type = _CMSGNETWORKDEVICEIP6ADDRESS
_CMSGNETWORKDEVICESDATA_DEVICE_WIRED.containing_type = _CMSGNETWORKDEVICESDATA_DEVICE
_CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP.containing_type = _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS
_CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS.fields_by_name['aps'].message_type = _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP
_CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS.containing_type = _CMSGNETWORKDEVICESDATA_DEVICE
_CMSGNETWORKDEVICESDATA_DEVICE.fields_by_name['ip4'].message_type = _CMSGNETWORKDEVICEIP4CONFIG
_CMSGNETWORKDEVICESDATA_DEVICE.fields_by_name['ip6'].message_type = _CMSGNETWORKDEVICEIP6CONFIG
_CMSGNETWORKDEVICESDATA_DEVICE.fields_by_name['wired'].message_type = _CMSGNETWORKDEVICESDATA_DEVICE_WIRED
_CMSGNETWORKDEVICESDATA_DEVICE.fields_by_name['wireless'].message_type = _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS
_CMSGNETWORKDEVICESDATA_DEVICE.containing_type = _CMSGNETWORKDEVICESDATA
_CMSGNETWORKDEVICESDATA.fields_by_name['devices'].message_type = _CMSGNETWORKDEVICESDATA_DEVICE
_CMSGNETWORKDEVICECONNECT_KNOWNAP.containing_type = _CMSGNETWORKDEVICECONNECT
_CMSGNETWORKDEVICECONNECT_CUSTOMAP.containing_type = _CMSGNETWORKDEVICECONNECT
_CMSGNETWORKDEVICECONNECT_CREDENTIALS.containing_type = _CMSGNETWORKDEVICECONNECT
_CMSGNETWORKDEVICECONNECT.fields_by_name['credentials'].message_type = _CMSGNETWORKDEVICECONNECT_CREDENTIALS
_CMSGNETWORKDEVICECONNECT.fields_by_name['ip4'].message_type = _CMSGNETWORKDEVICEIP4CONFIG
_CMSGNETWORKDEVICECONNECT.fields_by_name['ip6'].message_type = _CMSGNETWORKDEVICEIP6CONFIG
_CMSGNETWORKDEVICECONNECT.fields_by_name['ap_known'].message_type = _CMSGNETWORKDEVICECONNECT_KNOWNAP
_CMSGNETWORKDEVICECONNECT.fields_by_name['ap_custom'].message_type = _CMSGNETWORKDEVICECONNECT_CUSTOMAP
_CMSGNETWORKDEVICECONNECT.oneofs_by_name['ap_info'].fields.append(
  _CMSGNETWORKDEVICECONNECT.fields_by_name['ap_known'])
_CMSGNETWORKDEVICECONNECT.fields_by_name['ap_known'].containing_oneof = _CMSGNETWORKDEVICECONNECT.oneofs_by_name['ap_info']
_CMSGNETWORKDEVICECONNECT.oneofs_by_name['ap_info'].fields.append(
  _CMSGNETWORKDEVICECONNECT.fields_by_name['ap_custom'])
_CMSGNETWORKDEVICECONNECT.fields_by_name['ap_custom'].containing_oneof = _CMSGNETWORKDEVICECONNECT.oneofs_by_name['ap_info']
_CMSGSTORAGEDEVICESDATA_DRIVE.containing_type = _CMSGSTORAGEDEVICESDATA
_CMSGSTORAGEDEVICESDATA_BLOCKDEVICE.fields_by_name['content_type'].enum_type = enums__pb2._ESTORAGEBLOCKCONTENTTYPE
_CMSGSTORAGEDEVICESDATA_BLOCKDEVICE.fields_by_name['filesystem_type'].enum_type = enums__pb2._ESTORAGEBLOCKFILESYSTEMTYPE
_CMSGSTORAGEDEVICESDATA_BLOCKDEVICE.containing_type = _CMSGSTORAGEDEVICESDATA
_CMSGSTORAGEDEVICESDATA.fields_by_name['drives'].message_type = _CMSGSTORAGEDEVICESDATA_DRIVE
_CMSGSTORAGEDEVICESDATA.fields_by_name['block_devices'].message_type = _CMSGSTORAGEDEVICESDATA_BLOCKDEVICE
_CCLOUD_PENDINGREMOTEOPERATION.fields_by_name['operation'].enum_type = _ECLOUDPENDINGREMOTEOPERATION
_CMSGCLOUDPENDINGREMOTEOPERATIONS.fields_by_name['operations'].message_type = _CCLOUD_PENDINGREMOTEOPERATION
_CMSGBLUETOOTHDEVICESDATA_ADAPTER.containing_type = _CMSGBLUETOOTHDEVICESDATA
_CMSGBLUETOOTHDEVICESDATA_DEVICE.fields_by_name['etype'].enum_type = enums__pb2._EBLUETOOTHDEVICETYPE
_CMSGBLUETOOTHDEVICESDATA_DEVICE.containing_type = _CMSGBLUETOOTHDEVICESDATA
_CMSGBLUETOOTHDEVICESDATA_MANAGER.containing_type = _CMSGBLUETOOTHDEVICESDATA
_CMSGBLUETOOTHDEVICESDATA.fields_by_name['adapters'].message_type = _CMSGBLUETOOTHDEVICESDATA_ADAPTER
_CMSGBLUETOOTHDEVICESDATA.fields_by_name['devices'].message_type = _CMSGBLUETOOTHDEVICESDATA_DEVICE
_CMSGBLUETOOTHDEVICESDATA.fields_by_name['manager'].message_type = _CMSGBLUETOOTHDEVICESDATA_MANAGER
_CMSGSYSTEMPERFDIAGNOSTICINFO.fields_by_name['entries'].message_type = _CMSGSYSTEMPERFDIAGNOSTICENTRY
_CMSGSYSTEMPERFDIAGNOSTICINFO.fields_by_name['interfaces'].message_type = _CMSGSYSTEMPERFNETWORKINTERFACE
_CMSGSYSTEMPERFLIMITS.fields_by_name['gpu_performance_levels_available'].enum_type = enums__pb2._EGPUPERFORMANCELEVEL
_CMSGSYSTEMPERFSETTINGSGLOBAL.fields_by_name['system_trace_service_state'].enum_type = enums__pb2._ESYSTEMSERVICESTATE
_CMSGSYSTEMPERFSETTINGSGLOBAL.fields_by_name['graphics_profiling_service_state'].enum_type = enums__pb2._ESYSTEMSERVICESTATE
_CMSGSYSTEMPERFSETTINGSGLOBAL.fields_by_name['perf_overlay_service_state'].enum_type = enums__pb2._ESYSTEMSERVICESTATE
_CMSGSYSTEMPERFSETTINGSGLOBAL.fields_by_name['perf_overlay_level'].enum_type = enums__pb2._EGRAPHICSPERFOVERLAYLEVEL
_CMSGSYSTEMPERFSETTINGSPERAPP.fields_by_name['cpu_governor'].enum_type = enums__pb2._ECPUGOVERNOR
_CMSGSYSTEMPERFSETTINGSPERAPP.fields_by_name['gpu_performance_level'].enum_type = enums__pb2._EGPUPERFORMANCELEVEL
_CMSGSYSTEMPERFSETTINGS.fields_by_name['global'].message_type = _CMSGSYSTEMPERFSETTINGSGLOBAL
_CMSGSYSTEMPERFSETTINGS.fields_by_name['per_app'].message_type = _CMSGSYSTEMPERFSETTINGSPERAPP
_CMSGSYSTEMPERFSETTINGSV1.fields_by_name['system_trace_service_state'].enum_type = enums__pb2._ESYSTEMSERVICESTATE
_CMSGSYSTEMPERFSETTINGSV1.fields_by_name['graphics_profiling_service_state'].enum_type = enums__pb2._ESYSTEMSERVICESTATE
_CMSGSYSTEMPERFSETTINGSV1.fields_by_name['perf_overlay_service_state'].enum_type = enums__pb2._ESYSTEMSERVICESTATE
_CMSGSYSTEMPERFSETTINGSV1.fields_by_name['perf_overlay_level'].enum_type = enums__pb2._EGRAPHICSPERFOVERLAYLEVEL
_CMSGSYSTEMPERFSETTINGSV1.fields_by_name['gpu_performance_level'].enum_type = enums__pb2._EGPUPERFORMANCELEVEL
_CMSGSYSTEMPERFSETTINGSV1.fields_by_name['cpu_governor'].enum_type = enums__pb2._ECPUGOVERNOR
_CMSGSYSTEMPERFSTATE.fields_by_name['limits'].message_type = _CMSGSYSTEMPERFLIMITS
_CMSGSYSTEMPERFSTATE.fields_by_name['settings'].message_type = _CMSGSYSTEMPERFSETTINGS
_CMSGSYSTEMPERFUPDATESETTINGS.fields_by_name['settings_delta'].message_type = _CMSGSYSTEMPERFSETTINGS
_CMSGSYSTEMPERFUPDATESETTINGS.oneofs_by_name['update'].fields.append(
  _CMSGSYSTEMPERFUPDATESETTINGS.fields_by_name['reset_to_default'])
_CMSGSYSTEMPERFUPDATESETTINGS.fields_by_name['reset_to_default'].containing_oneof = _CMSGSYSTEMPERFUPDATESETTINGS.oneofs_by_name['update']
_CMSGSYSTEMPERFUPDATESETTINGS.oneofs_by_name['update'].fields.append(
  _CMSGSYSTEMPERFUPDATESETTINGS.fields_by_name['settings_delta'])
_CMSGSYSTEMPERFUPDATESETTINGS.fields_by_name['settings_delta'].containing_oneof = _CMSGSYSTEMPERFUPDATESETTINGS.oneofs_by_name['update']
_CMSGSYSTEMDOCKUPDATESTATE.fields_by_name['state'].enum_type = enums__pb2._EUPDATERSTATE
_CMSGSYSTEMDOCKSTATE.fields_by_name['update_state'].message_type = _CMSGSYSTEMDOCKUPDATESTATE
_CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY.fields_by_name['echannel'].enum_type = enums__pb2._ESYSTEMAUDIOCHANNEL
_CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY.containing_type = _CMSGSYSTEMAUDIOVOLUME
_CMSGSYSTEMAUDIOVOLUME.fields_by_name['entries'].message_type = _CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY
_CMSGSYSTEMAUDIOMANAGERDEVICE.fields_by_name['base'].message_type = _CMSGSYSTEMAUDIOMANAGEROBJECT
_CMSGSYSTEMAUDIOMANAGERNODE.fields_by_name['base'].message_type = _CMSGSYSTEMAUDIOMANAGEROBJECT
_CMSGSYSTEMAUDIOMANAGERNODE.fields_by_name['edirection'].enum_type = enums__pb2._ESYSTEMAUDIODIRECTION
_CMSGSYSTEMAUDIOMANAGERNODE.fields_by_name['volume'].message_type = _CMSGSYSTEMAUDIOVOLUME
_CMSGSYSTEMAUDIOMANAGERPORT.fields_by_name['base'].message_type = _CMSGSYSTEMAUDIOMANAGEROBJECT
_CMSGSYSTEMAUDIOMANAGERPORT.fields_by_name['etype'].enum_type = enums__pb2._ESYSTEMAUDIOPORTTYPE
_CMSGSYSTEMAUDIOMANAGERPORT.fields_by_name['edirection'].enum_type = enums__pb2._ESYSTEMAUDIOPORTDIRECTION
_CMSGSYSTEMAUDIOMANAGERLINK.fields_by_name['base'].message_type = _CMSGSYSTEMAUDIOMANAGEROBJECT
_CMSGSYSTEMAUDIOMANAGERSTATEHW.fields_by_name['devices'].message_type = _CMSGSYSTEMAUDIOMANAGERDEVICE
_CMSGSYSTEMAUDIOMANAGERSTATEHW.fields_by_name['nodes'].message_type = _CMSGSYSTEMAUDIOMANAGERNODE
_CMSGSYSTEMAUDIOMANAGERSTATEHW.fields_by_name['ports'].message_type = _CMSGSYSTEMAUDIOMANAGERPORT
_CMSGSYSTEMAUDIOMANAGERSTATEHW.fields_by_name['links'].message_type = _CMSGSYSTEMAUDIOMANAGERLINK
_CMSGSYSTEMAUDIOMANAGERSTATE.fields_by_name['hw'].message_type = _CMSGSYSTEMAUDIOMANAGERSTATEHW
_CMSGSYSTEMMANAGERSETTINGS.fields_by_name['display_colorprofile'].enum_type = enums__pb2._ECOLORPROFILE
_CMSGSYSTEMMANAGERSETTINGS.fields_by_name['fan_control_mode'].enum_type = enums__pb2._ESYSTEMFANCONTROLMODE
_CMSGSELECTOSBRANCHPARAMS.fields_by_name['branch'].enum_type = enums__pb2._EOSBRANCH
_CMSGSYSTEMUPDATECHECKRESULT.fields_by_name['type'].enum_type = enums__pb2._EUPDATERTYPE
_CMSGSYSTEMUPDATEAPPLYPARAMS.fields_by_name['apply_types'].enum_type = enums__pb2._EUPDATERTYPE
_CMSGSYSTEMUPDATEAPPLYRESULT.fields_by_name['type'].enum_type = enums__pb2._EUPDATERTYPE
_CMSGSYSTEMUPDATESTATE.fields_by_name['state'].enum_type = enums__pb2._EUPDATERSTATE
_CMSGSYSTEMUPDATESTATE.fields_by_name['progress'].message_type = _CMSGSYSTEMUPDATEPROGRESS
_CMSGSYSTEMUPDATESTATE.fields_by_name['update_check_results'].message_type = _CMSGSYSTEMUPDATECHECKRESULT
_CMSGSYSTEMUPDATESTATE.fields_by_name['update_apply_results'].message_type = _CMSGSYSTEMUPDATEAPPLYRESULT
_CMSGCELLLIST_CELL.containing_type = _CMSGCELLLIST
_CMSGCELLLIST.fields_by_name['cells'].message_type = _CMSGCELLLIST_CELL
DESCRIPTOR.message_types_by_name['SteamMessagesClientIClientForcedEnumDependencies'] = _STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES
DESCRIPTOR.message_types_by_name['CMsgNetworkDeviceIP4Address'] = _CMSGNETWORKDEVICEIP4ADDRESS
DESCRIPTOR.message_types_by_name['CMsgNetworkDeviceIP4Config'] = _CMSGNETWORKDEVICEIP4CONFIG
DESCRIPTOR.message_types_by_name['CMsgNetworkDeviceIP6Address'] = _CMSGNETWORKDEVICEIP6ADDRESS
DESCRIPTOR.message_types_by_name['CMsgNetworkDeviceIP6Config'] = _CMSGNETWORKDEVICEIP6CONFIG
DESCRIPTOR.message_types_by_name['CMsgNetworkDevicesData'] = _CMSGNETWORKDEVICESDATA
DESCRIPTOR.message_types_by_name['CMsgNetworkDeviceConnect'] = _CMSGNETWORKDEVICECONNECT
DESCRIPTOR.message_types_by_name['CMsgStorageDevicesData'] = _CMSGSTORAGEDEVICESDATA
DESCRIPTOR.message_types_by_name['CCloud_PendingRemoteOperation'] = _CCLOUD_PENDINGREMOTEOPERATION
DESCRIPTOR.message_types_by_name['CMsgCloudPendingRemoteOperations'] = _CMSGCLOUDPENDINGREMOTEOPERATIONS
DESCRIPTOR.message_types_by_name['CMsgBluetoothDevicesData'] = _CMSGBLUETOOTHDEVICESDATA
DESCRIPTOR.message_types_by_name['CMsgSystemPerfDiagnosticEntry'] = _CMSGSYSTEMPERFDIAGNOSTICENTRY
DESCRIPTOR.message_types_by_name['CMsgSystemPerfNetworkInterface'] = _CMSGSYSTEMPERFNETWORKINTERFACE
DESCRIPTOR.message_types_by_name['CMsgSystemPerfDiagnosticInfo'] = _CMSGSYSTEMPERFDIAGNOSTICINFO
DESCRIPTOR.message_types_by_name['CMsgSystemPerfLimits'] = _CMSGSYSTEMPERFLIMITS
DESCRIPTOR.message_types_by_name['CMsgSystemPerfSettingsGlobal'] = _CMSGSYSTEMPERFSETTINGSGLOBAL
DESCRIPTOR.message_types_by_name['CMsgSystemPerfSettingsPerApp'] = _CMSGSYSTEMPERFSETTINGSPERAPP
DESCRIPTOR.message_types_by_name['CMsgSystemPerfSettings'] = _CMSGSYSTEMPERFSETTINGS
DESCRIPTOR.message_types_by_name['CMsgSystemPerfSettingsV1'] = _CMSGSYSTEMPERFSETTINGSV1
DESCRIPTOR.message_types_by_name['CMsgSystemPerfState'] = _CMSGSYSTEMPERFSTATE
DESCRIPTOR.message_types_by_name['CMsgSystemPerfUpdateSettings'] = _CMSGSYSTEMPERFUPDATESETTINGS
DESCRIPTOR.message_types_by_name['CMsgSystemDockUpdateState'] = _CMSGSYSTEMDOCKUPDATESTATE
DESCRIPTOR.message_types_by_name['CMsgSystemDockState'] = _CMSGSYSTEMDOCKSTATE
DESCRIPTOR.message_types_by_name['CMsgSystemDockUpdateFirmware'] = _CMSGSYSTEMDOCKUPDATEFIRMWARE
DESCRIPTOR.message_types_by_name['CMsgSystemAudioVolume'] = _CMSGSYSTEMAUDIOVOLUME
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerObject'] = _CMSGSYSTEMAUDIOMANAGEROBJECT
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerDevice'] = _CMSGSYSTEMAUDIOMANAGERDEVICE
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerNode'] = _CMSGSYSTEMAUDIOMANAGERNODE
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerPort'] = _CMSGSYSTEMAUDIOMANAGERPORT
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerLink'] = _CMSGSYSTEMAUDIOMANAGERLINK
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerStateHW'] = _CMSGSYSTEMAUDIOMANAGERSTATEHW
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerState'] = _CMSGSYSTEMAUDIOMANAGERSTATE
DESCRIPTOR.message_types_by_name['CMsgSystemAudioManagerUpdateSomething'] = _CMSGSYSTEMAUDIOMANAGERUPDATESOMETHING
DESCRIPTOR.message_types_by_name['CMsgSystemManagerSettings'] = _CMSGSYSTEMMANAGERSETTINGS
DESCRIPTOR.message_types_by_name['CMsgSelectOSBranchParams'] = _CMSGSELECTOSBRANCHPARAMS
DESCRIPTOR.message_types_by_name['CMsgSystemUpdateProgress'] = _CMSGSYSTEMUPDATEPROGRESS
DESCRIPTOR.message_types_by_name['CMsgSystemUpdateCheckResult'] = _CMSGSYSTEMUPDATECHECKRESULT
DESCRIPTOR.message_types_by_name['CMsgSystemUpdateApplyParams'] = _CMSGSYSTEMUPDATEAPPLYPARAMS
DESCRIPTOR.message_types_by_name['CMsgSystemUpdateApplyResult'] = _CMSGSYSTEMUPDATEAPPLYRESULT
DESCRIPTOR.message_types_by_name['CMsgSystemUpdateState'] = _CMSGSYSTEMUPDATESTATE
DESCRIPTOR.message_types_by_name['CMsgAchievementChange'] = _CMSGACHIEVEMENTCHANGE
DESCRIPTOR.message_types_by_name['CMsgCellList'] = _CMSGCELLLIST
DESCRIPTOR.message_types_by_name['CMsgShortcutInfo'] = _CMSGSHORTCUTINFO
DESCRIPTOR.message_types_by_name['CMsgShortcutAppIds'] = _CMSGSHORTCUTAPPIDS
DESCRIPTOR.enum_types_by_name['ECloudPendingRemoteOperation'] = _ECLOUDPENDINGREMOTEOPERATION
DESCRIPTOR.enum_types_by_name['ESteamDeckKeyboardLayout'] = _ESTEAMDECKKEYBOARDLAYOUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SteamMessagesClientIClientForcedEnumDependencies = _reflection.GeneratedProtocolMessageType('SteamMessagesClientIClientForcedEnumDependencies', (_message.Message,), {
  'DESCRIPTOR' : _STEAMMESSAGESCLIENTICLIENTFORCEDENUMDEPENDENCIES,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:SteamMessagesClientIClientForcedEnumDependencies)
  })
_sym_db.RegisterMessage(SteamMessagesClientIClientForcedEnumDependencies)

CMsgNetworkDeviceIP4Address = _reflection.GeneratedProtocolMessageType('CMsgNetworkDeviceIP4Address', (_message.Message,), {
  'DESCRIPTOR' : _CMSGNETWORKDEVICEIP4ADDRESS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceIP4Address)
  })
_sym_db.RegisterMessage(CMsgNetworkDeviceIP4Address)

CMsgNetworkDeviceIP4Config = _reflection.GeneratedProtocolMessageType('CMsgNetworkDeviceIP4Config', (_message.Message,), {
  'DESCRIPTOR' : _CMSGNETWORKDEVICEIP4CONFIG,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceIP4Config)
  })
_sym_db.RegisterMessage(CMsgNetworkDeviceIP4Config)

CMsgNetworkDeviceIP6Address = _reflection.GeneratedProtocolMessageType('CMsgNetworkDeviceIP6Address', (_message.Message,), {
  'DESCRIPTOR' : _CMSGNETWORKDEVICEIP6ADDRESS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceIP6Address)
  })
_sym_db.RegisterMessage(CMsgNetworkDeviceIP6Address)

CMsgNetworkDeviceIP6Config = _reflection.GeneratedProtocolMessageType('CMsgNetworkDeviceIP6Config', (_message.Message,), {
  'DESCRIPTOR' : _CMSGNETWORKDEVICEIP6CONFIG,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceIP6Config)
  })
_sym_db.RegisterMessage(CMsgNetworkDeviceIP6Config)

CMsgNetworkDevicesData = _reflection.GeneratedProtocolMessageType('CMsgNetworkDevicesData', (_message.Message,), {

  'Device' : _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {

    'Wired' : _reflection.GeneratedProtocolMessageType('Wired', (_message.Message,), {
      'DESCRIPTOR' : _CMSGNETWORKDEVICESDATA_DEVICE_WIRED,
      '__module__' : 'steammessages_client_objects_pb2'
      # @@protoc_insertion_point(class_scope:CMsgNetworkDevicesData.Device.Wired)
      })
    ,

    'Wireless' : _reflection.GeneratedProtocolMessageType('Wireless', (_message.Message,), {

      'AP' : _reflection.GeneratedProtocolMessageType('AP', (_message.Message,), {
        'DESCRIPTOR' : _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS_AP,
        '__module__' : 'steammessages_client_objects_pb2'
        # @@protoc_insertion_point(class_scope:CMsgNetworkDevicesData.Device.Wireless.AP)
        })
      ,
      'DESCRIPTOR' : _CMSGNETWORKDEVICESDATA_DEVICE_WIRELESS,
      '__module__' : 'steammessages_client_objects_pb2'
      # @@protoc_insertion_point(class_scope:CMsgNetworkDevicesData.Device.Wireless)
      })
    ,
    'DESCRIPTOR' : _CMSGNETWORKDEVICESDATA_DEVICE,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgNetworkDevicesData.Device)
    })
  ,
  'DESCRIPTOR' : _CMSGNETWORKDEVICESDATA,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNetworkDevicesData)
  })
_sym_db.RegisterMessage(CMsgNetworkDevicesData)
_sym_db.RegisterMessage(CMsgNetworkDevicesData.Device)
_sym_db.RegisterMessage(CMsgNetworkDevicesData.Device.Wired)
_sym_db.RegisterMessage(CMsgNetworkDevicesData.Device.Wireless)
_sym_db.RegisterMessage(CMsgNetworkDevicesData.Device.Wireless.AP)

CMsgNetworkDeviceConnect = _reflection.GeneratedProtocolMessageType('CMsgNetworkDeviceConnect', (_message.Message,), {

  'KnownAP' : _reflection.GeneratedProtocolMessageType('KnownAP', (_message.Message,), {
    'DESCRIPTOR' : _CMSGNETWORKDEVICECONNECT_KNOWNAP,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceConnect.KnownAP)
    })
  ,

  'CustomAP' : _reflection.GeneratedProtocolMessageType('CustomAP', (_message.Message,), {
    'DESCRIPTOR' : _CMSGNETWORKDEVICECONNECT_CUSTOMAP,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceConnect.CustomAP)
    })
  ,

  'Credentials' : _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), {
    'DESCRIPTOR' : _CMSGNETWORKDEVICECONNECT_CREDENTIALS,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceConnect.Credentials)
    })
  ,
  'DESCRIPTOR' : _CMSGNETWORKDEVICECONNECT,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgNetworkDeviceConnect)
  })
_sym_db.RegisterMessage(CMsgNetworkDeviceConnect)
_sym_db.RegisterMessage(CMsgNetworkDeviceConnect.KnownAP)
_sym_db.RegisterMessage(CMsgNetworkDeviceConnect.CustomAP)
_sym_db.RegisterMessage(CMsgNetworkDeviceConnect.Credentials)

CMsgStorageDevicesData = _reflection.GeneratedProtocolMessageType('CMsgStorageDevicesData', (_message.Message,), {

  'Drive' : _reflection.GeneratedProtocolMessageType('Drive', (_message.Message,), {
    'DESCRIPTOR' : _CMSGSTORAGEDEVICESDATA_DRIVE,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgStorageDevicesData.Drive)
    })
  ,

  'BlockDevice' : _reflection.GeneratedProtocolMessageType('BlockDevice', (_message.Message,), {
    'DESCRIPTOR' : _CMSGSTORAGEDEVICESDATA_BLOCKDEVICE,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgStorageDevicesData.BlockDevice)
    })
  ,
  'DESCRIPTOR' : _CMSGSTORAGEDEVICESDATA,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgStorageDevicesData)
  })
_sym_db.RegisterMessage(CMsgStorageDevicesData)
_sym_db.RegisterMessage(CMsgStorageDevicesData.Drive)
_sym_db.RegisterMessage(CMsgStorageDevicesData.BlockDevice)

CCloud_PendingRemoteOperation = _reflection.GeneratedProtocolMessageType('CCloud_PendingRemoteOperation', (_message.Message,), {
  'DESCRIPTOR' : _CCLOUD_PENDINGREMOTEOPERATION,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CCloud_PendingRemoteOperation)
  })
_sym_db.RegisterMessage(CCloud_PendingRemoteOperation)

CMsgCloudPendingRemoteOperations = _reflection.GeneratedProtocolMessageType('CMsgCloudPendingRemoteOperations', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLOUDPENDINGREMOTEOPERATIONS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCloudPendingRemoteOperations)
  })
_sym_db.RegisterMessage(CMsgCloudPendingRemoteOperations)

CMsgBluetoothDevicesData = _reflection.GeneratedProtocolMessageType('CMsgBluetoothDevicesData', (_message.Message,), {

  'Adapter' : _reflection.GeneratedProtocolMessageType('Adapter', (_message.Message,), {
    'DESCRIPTOR' : _CMSGBLUETOOTHDEVICESDATA_ADAPTER,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgBluetoothDevicesData.Adapter)
    })
  ,

  'Device' : _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
    'DESCRIPTOR' : _CMSGBLUETOOTHDEVICESDATA_DEVICE,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgBluetoothDevicesData.Device)
    })
  ,

  'Manager' : _reflection.GeneratedProtocolMessageType('Manager', (_message.Message,), {
    'DESCRIPTOR' : _CMSGBLUETOOTHDEVICESDATA_MANAGER,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgBluetoothDevicesData.Manager)
    })
  ,
  'DESCRIPTOR' : _CMSGBLUETOOTHDEVICESDATA,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgBluetoothDevicesData)
  })
_sym_db.RegisterMessage(CMsgBluetoothDevicesData)
_sym_db.RegisterMessage(CMsgBluetoothDevicesData.Adapter)
_sym_db.RegisterMessage(CMsgBluetoothDevicesData.Device)
_sym_db.RegisterMessage(CMsgBluetoothDevicesData.Manager)

CMsgSystemPerfDiagnosticEntry = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfDiagnosticEntry', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFDIAGNOSTICENTRY,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfDiagnosticEntry)
  })
_sym_db.RegisterMessage(CMsgSystemPerfDiagnosticEntry)

CMsgSystemPerfNetworkInterface = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfNetworkInterface', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFNETWORKINTERFACE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfNetworkInterface)
  })
_sym_db.RegisterMessage(CMsgSystemPerfNetworkInterface)

CMsgSystemPerfDiagnosticInfo = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfDiagnosticInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFDIAGNOSTICINFO,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfDiagnosticInfo)
  })
_sym_db.RegisterMessage(CMsgSystemPerfDiagnosticInfo)

CMsgSystemPerfLimits = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfLimits', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFLIMITS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfLimits)
  })
_sym_db.RegisterMessage(CMsgSystemPerfLimits)

CMsgSystemPerfSettingsGlobal = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfSettingsGlobal', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFSETTINGSGLOBAL,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfSettingsGlobal)
  })
_sym_db.RegisterMessage(CMsgSystemPerfSettingsGlobal)

CMsgSystemPerfSettingsPerApp = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfSettingsPerApp', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFSETTINGSPERAPP,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfSettingsPerApp)
  })
_sym_db.RegisterMessage(CMsgSystemPerfSettingsPerApp)

CMsgSystemPerfSettings = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfSettings', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFSETTINGS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfSettings)
  })
_sym_db.RegisterMessage(CMsgSystemPerfSettings)

CMsgSystemPerfSettingsV1 = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfSettingsV1', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFSETTINGSV1,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfSettingsV1)
  })
_sym_db.RegisterMessage(CMsgSystemPerfSettingsV1)

CMsgSystemPerfState = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFSTATE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfState)
  })
_sym_db.RegisterMessage(CMsgSystemPerfState)

CMsgSystemPerfUpdateSettings = _reflection.GeneratedProtocolMessageType('CMsgSystemPerfUpdateSettings', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMPERFUPDATESETTINGS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemPerfUpdateSettings)
  })
_sym_db.RegisterMessage(CMsgSystemPerfUpdateSettings)

CMsgSystemDockUpdateState = _reflection.GeneratedProtocolMessageType('CMsgSystemDockUpdateState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMDOCKUPDATESTATE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemDockUpdateState)
  })
_sym_db.RegisterMessage(CMsgSystemDockUpdateState)

CMsgSystemDockState = _reflection.GeneratedProtocolMessageType('CMsgSystemDockState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMDOCKSTATE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemDockState)
  })
_sym_db.RegisterMessage(CMsgSystemDockState)

CMsgSystemDockUpdateFirmware = _reflection.GeneratedProtocolMessageType('CMsgSystemDockUpdateFirmware', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMDOCKUPDATEFIRMWARE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemDockUpdateFirmware)
  })
_sym_db.RegisterMessage(CMsgSystemDockUpdateFirmware)

CMsgSystemAudioVolume = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioVolume', (_message.Message,), {

  'ChannelEntry' : _reflection.GeneratedProtocolMessageType('ChannelEntry', (_message.Message,), {
    'DESCRIPTOR' : _CMSGSYSTEMAUDIOVOLUME_CHANNELENTRY,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgSystemAudioVolume.ChannelEntry)
    })
  ,
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOVOLUME,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioVolume)
  })
_sym_db.RegisterMessage(CMsgSystemAudioVolume)
_sym_db.RegisterMessage(CMsgSystemAudioVolume.ChannelEntry)

CMsgSystemAudioManagerObject = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerObject', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGEROBJECT,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerObject)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerObject)

CMsgSystemAudioManagerDevice = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerDevice', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERDEVICE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerDevice)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerDevice)

CMsgSystemAudioManagerNode = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerNode', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERNODE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerNode)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerNode)

CMsgSystemAudioManagerPort = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerPort', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERPORT,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerPort)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerPort)

CMsgSystemAudioManagerLink = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerLink', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERLINK,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerLink)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerLink)

CMsgSystemAudioManagerStateHW = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerStateHW', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERSTATEHW,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerStateHW)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerStateHW)

CMsgSystemAudioManagerState = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERSTATE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerState)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerState)

CMsgSystemAudioManagerUpdateSomething = _reflection.GeneratedProtocolMessageType('CMsgSystemAudioManagerUpdateSomething', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMAUDIOMANAGERUPDATESOMETHING,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemAudioManagerUpdateSomething)
  })
_sym_db.RegisterMessage(CMsgSystemAudioManagerUpdateSomething)

CMsgSystemManagerSettings = _reflection.GeneratedProtocolMessageType('CMsgSystemManagerSettings', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMMANAGERSETTINGS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemManagerSettings)
  })
_sym_db.RegisterMessage(CMsgSystemManagerSettings)

CMsgSelectOSBranchParams = _reflection.GeneratedProtocolMessageType('CMsgSelectOSBranchParams', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSELECTOSBRANCHPARAMS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSelectOSBranchParams)
  })
_sym_db.RegisterMessage(CMsgSelectOSBranchParams)

CMsgSystemUpdateProgress = _reflection.GeneratedProtocolMessageType('CMsgSystemUpdateProgress', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMUPDATEPROGRESS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemUpdateProgress)
  })
_sym_db.RegisterMessage(CMsgSystemUpdateProgress)

CMsgSystemUpdateCheckResult = _reflection.GeneratedProtocolMessageType('CMsgSystemUpdateCheckResult', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMUPDATECHECKRESULT,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemUpdateCheckResult)
  })
_sym_db.RegisterMessage(CMsgSystemUpdateCheckResult)

CMsgSystemUpdateApplyParams = _reflection.GeneratedProtocolMessageType('CMsgSystemUpdateApplyParams', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMUPDATEAPPLYPARAMS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemUpdateApplyParams)
  })
_sym_db.RegisterMessage(CMsgSystemUpdateApplyParams)

CMsgSystemUpdateApplyResult = _reflection.GeneratedProtocolMessageType('CMsgSystemUpdateApplyResult', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMUPDATEAPPLYRESULT,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemUpdateApplyResult)
  })
_sym_db.RegisterMessage(CMsgSystemUpdateApplyResult)

CMsgSystemUpdateState = _reflection.GeneratedProtocolMessageType('CMsgSystemUpdateState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSYSTEMUPDATESTATE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgSystemUpdateState)
  })
_sym_db.RegisterMessage(CMsgSystemUpdateState)

CMsgAchievementChange = _reflection.GeneratedProtocolMessageType('CMsgAchievementChange', (_message.Message,), {
  'DESCRIPTOR' : _CMSGACHIEVEMENTCHANGE,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgAchievementChange)
  })
_sym_db.RegisterMessage(CMsgAchievementChange)

CMsgCellList = _reflection.GeneratedProtocolMessageType('CMsgCellList', (_message.Message,), {

  'Cell' : _reflection.GeneratedProtocolMessageType('Cell', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCELLLIST_CELL,
    '__module__' : 'steammessages_client_objects_pb2'
    # @@protoc_insertion_point(class_scope:CMsgCellList.Cell)
    })
  ,
  'DESCRIPTOR' : _CMSGCELLLIST,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgCellList)
  })
_sym_db.RegisterMessage(CMsgCellList)
_sym_db.RegisterMessage(CMsgCellList.Cell)

CMsgShortcutInfo = _reflection.GeneratedProtocolMessageType('CMsgShortcutInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSHORTCUTINFO,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgShortcutInfo)
  })
_sym_db.RegisterMessage(CMsgShortcutInfo)

CMsgShortcutAppIds = _reflection.GeneratedProtocolMessageType('CMsgShortcutAppIds', (_message.Message,), {
  'DESCRIPTOR' : _CMSGSHORTCUTAPPIDS,
  '__module__' : 'steammessages_client_objects_pb2'
  # @@protoc_insertion_point(class_scope:CMsgShortcutAppIds)
  })
_sym_db.RegisterMessage(CMsgShortcutAppIds)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
